<?php

abstract class DozentLMS_Addon {

	/**
	 * ID of this Addon, it will be addon directory name
	 *
	 * @var string
	 */

	public $id;

	/**
	 * Type of the addon. free|pro
	 * Set 'pro' if the addon is pro or coming from the DozentLMS Pro version.
	 *
	 * @var string free, pro
	 */

	public $type = 'free';

	public $is_pro = false;

	/**
	 * Name of the addon
	 *
	 * @var string
	 */
	public $name;

	/**
	 * Description of the addon
	 *
	 * @var string
	 */
	public $description;

	/**
	 * is the addon enabled or not.
	 *
	 * @var bool
	 */
	public $enabled;

	/**
	 * Thumbnail Src
	 *
	 * @var string
	 */

	public $thumbnail_src;

	/**
	 * List all dependent plugins for this addon.
	 *
	 * @var array
	 */
	public $dependency = [];

	public $required_plugins = [];

	/**
	 * Developer name
	 *
	 * @var string
	 */

	public $developer_name;

	/**
	 * Developer URL
	 *
	 * @var string
	 */
	public $developer_url;

	/**
	 * Method must have in the addon class. it's an alias of __construct()
	 *
	 * @return mixed
	 */

	abstract protected function init();

	public function __construct() {
		$this->enabled = $this->is_enabled();
		$this->is_pro  = ( $this->type === 'pro' );

		//Getting the addon thumbnail src
		if ( empty( $this->thumbnail_src ) ) {
			$thumbnail_src = DOZENTLMS_URL . 'resources/images/placeholder-plugin.png';

			$addon_dir = null;

			try {
				$class_info = new ReflectionClass( $this );
				$addon_dir  = trailingslashit( dirname( $class_info->getFileName() ) );
				$addon_url =  content_url( substr( $addon_dir, strlen( trailingslashit( WP_CONTENT_DIR ) ) ) );

				if ( file_exists( $addon_dir . "thumbnail.svg" ) ) {
					$thumbnail_src = $addon_url . "thumbnail.svg";
				} elseif ( file_exists( $addon_dir . "thumbnail.png" ) ) {
					$thumbnail_src = $addon_url . "thumbnail.png";
				} elseif ( file_exists( $addon_dir . "thumbnail.jpg" ) ) {
					$thumbnail_src = $addon_url . "thumbnail.jpg";
				} elseif ( file_exists( $addon_dir . "thumbnail.jpeg" ) ) {
					$thumbnail_src = $addon_url . "thumbnail.jpeg";
				}

			} catch ( Exception $e ) {
				//
			}

			$this->thumbnail_src = apply_filters( 'dozentlms_addon_thumbnail_src', $thumbnail_src, $this->id, $addon_dir );
		}

		//Setting require plugins
		$active_plugins = (array) get_option( 'active_plugins' );
		if ( is_array( $this->dependency ) && count( $this->dependency ) ) {
			foreach ( $this->dependency as $plugin_base => $plugin_name ) {
				if ( in_array( $plugin_base, $active_plugins ) ) {
					unset( $this->dependency[ $plugin_base ] );
				}
			}

			/**
			 * If any dependency plugin required install, disable the addon.
			 */

			if ( $this->enabled && is_array( $this->dependency ) && count( $this->dependency ) ) {
				$this->disable();
				$this->enabled = false;
			}
		}

		//Setting default developer name
		if ( empty( $this->developer_name ) ) {
			$this->developer_name = __( 'Dozent LMS Team', 'dozent-lms' );
		}

		//Setting default developer URL
		if ( empty( $this->developer_url ) ) {
			$this->developer_url = 'https://www.dozentlms.com';
		}

		/**
		 * is enable should always check after calling the parent constructor.
		 */

		if ( $this->enabled ) {
			$this->init();
		}
	}

	public function is_enabled() {
		$activated_addons = (array) get_option( 'dozentlms_active_addons' );

		return in_array( $this->id, array_filter( $activated_addons ) );
	}

	public function disable(){
		if ( $this->is_enabled() ) {
			$activated_addons = (array) get_option( 'dozentlms_active_addons' );
			$activated_addons = array_diff( $activated_addons, [ $this->id ] );

			update_option( 'dozentlms_active_addons', $activated_addons );
		}
	}


}