<?php

namespace DozentLMS\addons;

defined( 'ABSPATH' ) || exit;

class Load {

	public $addons;

	public function __construct() {
		add_action( 'wp_ajax_dozentlms_addon_toggle', [ $this, 'addon_toggle' ] );
		$this->load_addons_base();
	}

	/**
	 * Activate or deactivate Add-Ons from the core
	 */
	public function addon_toggle() {
		$addon_post_name = dozentlms_request_text( 'addon_name' );
		$is_activated    = ( dozentlms_request_text( 'is_activated' ) == 'true' );
		preg_match( "/dozentlms_addon\[(.*)\]/", $addon_post_name, $match );
		$addon_id = dozentlms_arr_get( $match, 1 );

		$activated_addons = (array) get_option( 'dozentlms_active_addons' );
		$activated_addons = array_filter( $activated_addons );

		if ( $is_activated ) {
			$activated_addons[] = $addon_id;
		} elseif ( in_array( $addon_id, $activated_addons ) ) {
			$activated_addons = array_diff( $activated_addons, [ $addon_id ] );
		}

		$activated_addons = array_unique( $activated_addons );

		update_option( 'dozentlms_active_addons', $activated_addons );
	}

	public function load_addons_base() {
		$addon_path_pattern = trailingslashit( DOZENTLMS_ABSPATH ) . 'addons/*';
		$addons_directories = glob( $addon_path_pattern, GLOB_ONLYDIR );

		if ( dozentlms_arr_count( $addons_directories ) ) {
			foreach ( $addons_directories as $directory ) {
				$addon_base_file = trailingslashit( $directory ) . basename( $directory ) . '.php';

				if ( is_file( $addon_base_file ) ) {
					require $addon_base_file;
				}
			}
		}
	}

}