<?php
defined( 'ABSPATH' ) || exit;

class DozentLMS_Addon_Frontend_Course_Builder extends DozentLMS_Addon {

	public function __construct() {
		$this->id   = 'frontend-course-builder';
		$this->name = __( 'Front-End Course Builder', 'dozent-lms' );
		$this->description
		            = __( 'Create or edit the course with the flexible and user-friendly front-end course builder without going to the traditional WordPress dashboard.',
			'dozent-lms' );

		parent::__construct();
	}

	public function init() {
		if ( ! dozentlms_is_instructor() ) {
			return;
		}

		add_filter( 'dozentlms_settings_args', [ $this, 'add_settings_fields' ] );

		add_filter( 'dozentlms_dashboard_tmpl', [ $this, 'load_fcb_tmpl' ], 99, 2 );
		add_action( 'dozentlms/frontend/course/builder/area', [ $this, 'frontend_course_builder' ] );
		add_filter( 'dozentlms_course_data_field_attrs', [ $this, 'frontend_course_builder_field_attrs' ] );

		//Course Data Tab for Frontend
		add_action( 'dozentlms/course_data/before_form/course_info', [ $this, 'render_course_info' ] );

		//Save Course
		add_action( 'template_redirect', [ $this, 'save_course' ] );
		add_action( 'wp_ajax_fcb_save', [ $this, 'save_course' ] );
	}

	public function add_settings_fields( $fields ) {

		$fields['frontend_course_builder'] = apply_filters( 'dozentlms_settings_frontend_course_builder_args', [
			'title'       => __( 'Front-End Course Builder', 'dozent-lms' ),
			'form_fields' => [
				'general' => [
					'title'        => __( 'Front-End Course Builder Settings', 'dozent-lms' ),
					'input_fields' => [

						'allow_instructor_publish_course' => [
							'type'        => 'switch',
							'label'       => __( 'Publish Course', 'dozent-lms' ),
							'title'       => __( 'Enable', 'dozent-lms' ),
							'description' => __( 'Allow instructor to publish their course directly from the frontend course builder.',
								'dozent-lms' ),
						],

						'fcb_auto_save' => [
							'type'  => 'switch',
							'label' => __( 'Auto Save', 'dozent-lms' ),
							'title' => __( 'Enable', 'dozent-lms' ),
						],

						'fcb_auto_save_time_interval' => [
							'type'        => 'number',
							'label'       => __( 'Auto Save Time Interval', 'dozent-lms' ),
							'title'       => __( 'Enable', 'dozent-lms' ),
							'default'     => 30,
							'min'         => 30,
							'description' => __( 'Specify time interval in seconds for auto save', 'dozent-lms' ),
						],

					]
				]
			]
		] );


		return $fields;
	}

	public function load_fcb_tmpl( $tmpl, $slug ){
		if ( "dashboard/home" !== $slug ) {
			return $tmpl;
		}

		$dashboard_page_slug = get_query_var( 'dbsegment' );
		$fcb_slugs = apply_filters( 'dozentlms_frontend_course_builder_page_slugs', [ 'create-new-course', 'edit-course' ] );

		if ( in_array( $dashboard_page_slug, $fcb_slugs ) ) {
			$tmpl = dozentlms_locate_template( 'dashboard/course-builder' );
		}

		return $tmpl;
	}

	public function frontend_course_builder() {
		global $post;

		wp_reset_query();

		$courseID = (int) dozentlms_get_var( 'course' );

		if ( ! $courseID ) {
			$courseID = wp_insert_post( [
				'post_type'   => 'dozentlms_course',
				'post_title'  => __( 'Course Auto Draft', 'dozent-lms' ),
				'post_status' => 'auto-draft'
			] );
		}

		$post = get_post( $courseID );
		setup_postdata( $post );

		/**
		 * Include course builder files.
		 */

		echo "<input type='hidden' name='dlms_action' value='fcb_save_course' />";
		echo "<input type='hidden' name='fcb_course_id' value='{$courseID}' />";
		require DOZENTLMS_ABSPATH . '/core/course/coursebuilder_header.php';
		require DOZENTLMS_ABSPATH . '/core/course/data.php';

		wp_reset_query();
	}

	public function frontend_course_builder_field_attrs( $fields ) {
		if ( is_admin() ) {
			return $fields;
		}

		$frontend_fields                = [];
		$frontend_fields['course_info'] = [ 'title' => __( 'Course Info', 'dozent-lms' ), ];

		$fields = array_merge( $frontend_fields, $fields );

		return $fields;
	}

	public function render_course_info() {
		require DOZENTLMS_ABSPATH . '/core/course/course_info.php';
	}

	public function save_course() {
		if ( ! dozentlms_is_frontend_dashboard() && ! dozentlms_is_ajax() ) {
			return;
		}

		$action = dozentlms_request_text( 'dlms_action' );
		if ( 'fcb_save_course' !== $action ) {
			return;
		}

		$course_id     = dozentlms_request_text( 'fcb_course_id' );
		$_thumbnail_id = dozentlms_request_text( '_thumbnail_id' );
		$course_title  = dozentlms_request_text( 'course_title' );
		$description   = isset( $_POST['course_description'] ) ? wp_kses_post( $_POST['course_description'] ) : '';
		$excerpt       = dozentlms_request_textarea( 'excerpt' );

		$courseArr = [
			'ID'           => $course_id,
			'post_title'   => $course_title,
			'post_name'    => sanitize_title( $course_title ),
			'post_content' => $description,
			'post_excerpt' => $excerpt,
		];

		if ( ! empty( $_thumbnail_id ) ) {
			$courseArr['_thumbnail_id'] = $_thumbnail_id;
		}

		$course = get_post( $course_id );

		$is_autosave = false;
		if ( dozentlms_is_ajax() && 'false' != dozentlms_request_text( 'fcb_autosave' ) ) {
			$is_autosave = true;
		}

		if ( ! $is_autosave ) {
			$saving_method = dozentlms_request_text( 'fcb_save_button' );
			if ( 'publish' !== $saving_method ) {
				$saving_method = 'save';
			}

			if ( $course->post_status !== 'publish' ) {
				if ( $saving_method === 'save' ) {
					$courseArr['post_status'] = 'draft_course';
				} else {

					if ( dozentlms_current_user_can_publish_course() ) {
						$courseArr['post_status'] = 'publish';
					} else {
						$courseArr['post_status'] = 'pending';
					}
				}
			}
		}

		wp_update_post( $courseArr );
		do_action( 'dozentlms/fcb/save_course' );

		if ( ! dozentlms_is_ajax() ) {
			wp_redirect( dozentlms_dashboard_link( 'my-courses-as-instructor' ) );
			exit();
		}

		wp_send_json_success();
	}

}

dozentlms_addon_register( 'DozentLMS_Addon_Frontend_Course_Builder' );