<?php
defined( 'ABSPATH' ) || exit;

class DozentLMS_Addon_Social_Login extends DozentLMS_Addon {

	public function __construct() {
		$this->id   = 'social-login';
		$this->name = __( 'Social Login', 'dozent-lms' );
		$this->description
		            = __( 'Social Login Add-On allows your users to get logged in instantly to your LMS platform.',
			'dozent-lms' );

		parent::__construct();
	}

	public function init() {
		add_filter( 'dozentlms_settings_social_login_args', [ $this, 'social_login_fields' ] );
		add_action( 'template_redirect', [ $this, 'social_login_attempt' ] );
	}

	/**
	 * Attempt from $_GET method
	 *
	 * @var string
	 */

	private $attempt;

	public function social_login_fields( $fields ) {

		$social_login_providers        = dozentlms_social_login_providers();
		$social_login_providers_fields = [];
		foreach ( $social_login_providers as $provider => $provide_name ) {
			$app_settings = '';
			if ( 'facebook' === $provider ) {
				$app_settings
					= sprintf( __( '%s Create an app %s if you don\'t have any. Fill client ID with your App ID and client secret field with App Secret. Add below Callback URL to Facebook app settings > Valid OAuth Redirect URIs',
					'dozent-lms' ), '<a href="https://developers.facebook.com/apps/" target="_blank">', '</a>' );
			} elseif ( 'google' === $provider ) {
				$app_settings
					= sprintf( __( '%s Create an App (Project) %s if you don\'t have any. Fill client ID and client Secret fields. Add below Callback URL to Authorized redirect URI',
					'dozent-lms' ), '<a href="https://console.cloud.google.com/apis/credentials" target="_blank">',
					'</a>' );
			}

			$social_login_providers_fields[ $provider ] = [
				'title'        => $provide_name,
				'input_fields' => [
					"{$provider}_app_settings_doc" => [
						'label'       => $provide_name . ' ' . __( 'App Settings', 'dozent-lms' ),
						'description' => $app_settings,
					],

					"enable_{$provider}_login"  => [
						'type'  => 'switch',
						'label' => __( 'Enable', 'dozent-lms' ),
					],
					"{$provider}_callback_url"  => [
						'type'    => 'text_disabled',
						'label'   => __( 'Callback URL', 'dozent-lms' ),
						'default' => dozentlms_get_login_url( "{$provider}-callback" ),
					],
					"{$provider}_client_id"     => [
						'type'  => 'text',
						'label' => __( 'Client ID', 'dozent-lms' ),
					],
					"{$provider}_client_secret" => [
						'type'  => 'text',
						'label' => __( 'Client Secret', 'dozent-lms' ),
					],

				],
			];
		}

		$social_login_common_fields = [
			'social_login' => [
				'title'        => __( 'Social Login', 'dozent-lms' ),
				'description'  => __( 'This section contains social login credentials.',
					'dozent-lms' ),
				'input_fields' => [

					'social_login_redirection_page' => [
						'type'        => 'radio',
						'label'       => __( 'Redirection Page', 'dozent-lms' ),
						'description' => __( 'Where do you want to redirect after login with a social platform?',
							'dozent-lms' ),
						'options'     => [
							'dashboard'    => __( 'Dashboard', 'dozent-lms' ),
							'samepage'     => __( 'Same Page', 'dozent-lms' ),
							'homepage'     => __( 'Home Page', 'dozent-lms' ),
							'profile_page' => __( 'Profile Page', 'dozent-lms' ),
						],
					],

				],
			]
		];

		$fields['form_fields'] = array_merge( $fields['form_fields'], $social_login_common_fields,
			$social_login_providers_fields );

		return $fields;
	}

	/**
	 * Social Login Attempts
	 */


	public function social_login_attempt() {
		$this->attempt = get_query_var( 'social_login_attempt' );

		if ( false !== strpos( $this->attempt, 'facebook' ) ) {
			$this->facebook_login();
		}

		if ( false !== strpos( $this->attempt, 'google' ) ) {
			$this->google_login();
		}

		do_action( 'dozentlms_social_login_attempt', $this->attempt );
	}

	private function facebook_login() {
		$redirect_uri = dozentlms_get_setting( 'facebook_callback_url' );
		$client_id    = dozentlms_get_setting( 'facebook_client_id' );
		$client_secret = dozentlms_get_setting( 'facebook_client_secret' );

		//Redirect to provider for the authorization
		if ( 'facebook' === $this->attempt ) {
			$redirect_to = add_query_arg( [
				'client_id'     => $client_id,
				'response_type' => 'code',
				'redirect_uri'  => urlencode( $redirect_uri )
			], 'https://www.facebook.com/v10.0/dialog/oauth' );

			wp_redirect( $redirect_to );
			exit();
		}

		//Provider returns with oauth code
		if ( 'facebook-callback' === $this->attempt ) {
			$code = dozentlms_get_var( 'code' );
			if ( empty( $code ) ) {
				return;
			}

			$request_url
				= "https://graph.facebook.com/oauth/access_token?client_id={$client_id}&redirect_uri={$redirect_uri}&client_secret={$client_secret}&code=$code";

			$response      = wp_remote_get( $request_url );
			$response_json = json_decode( wp_remote_retrieve_body( $response ), true );
			$access_token  = dozentlms_arr_get( $response_json, 'access_token' );

			if ( ! empty( $access_token ) ) {

				$inspect_token_url
					                         = "https://graph.facebook.com/debug_token?input_token={$access_token}&access_token=$access_token";
				$inspect_token_response      = wp_remote_get( $inspect_token_url );
				$inspect_token_response_json = json_decode( wp_remote_retrieve_body( $inspect_token_response ), true );

				$social_user_id = dozentlms_arr_get( $inspect_token_response_json, 'data.user_id' );

				if ( ! empty( $social_user_id ) ) {
					$user_data_response
						                     = wp_remote_get( "https://graph.facebook.com/{$social_user_id}/?fields=name,email&access_token={$access_token}" );
					$user_data_response_json = json_decode( wp_remote_retrieve_body( $user_data_response ), true );

					$name  = dozentlms_arr_get( $user_data_response_json, 'name' );
					$email = dozentlms_arr_get( $user_data_response_json, 'email' );

					$user_data = [
						'social_user_id' => $social_user_id,
						'provider'       => 'facebook',
						'name'           => $name,
						'email'          => $email,
					];

					$this->create_or_register_user( $user_data );
				}
			}

		}

	}

	public function google_login() {
		$redirect_uri  = dozentlms_get_setting( 'google_callback_url' );
		$client_id     = dozentlms_get_setting( 'google_client_id' );
		$client_secret = dozentlms_get_setting( 'google_client_secret' );

		//Redirect to provider for the authorization
		if ( 'google' === $this->attempt ) {
			$scopes = urlencode( implode( ' ', [ 'email', 'profile' ] ) );

			$auth_url = add_query_arg( [
				'approval_prompt' => 'force',
				'scope'           => $scopes,
				'client_id'       => $client_id,
				'redirect_uri'    => urlencode( $redirect_uri ),
				'response_type'   => 'code',
				'access_type'     => 'offline',
				'state'           => 'wp-random-string',

			], "https://accounts.google.com/o/oauth2/auth" );

			wp_redirect( $auth_url );
			exit();
		}

		if ( 'google-callback' === $this->attempt ) {
			$code = dozentlms_get_var( 'code' );
			if ( empty( $code ) ) {
				return;
			}

			$http_args = array(
				'timeout'    => 15,
				'user-agent' => 'DozentLMS',
				'body'       => array(
					'grant_type'    => 'authorization_code',
					'code'          => $code,
					'redirect_uri'  => $redirect_uri,
					'client_id'     => $client_id,
					'client_secret' => $client_secret
				)
			);

			$request      = wp_remote_post( 'https://accounts.google.com/o/oauth2/token', $http_args );
			$request      = json_decode( wp_remote_retrieve_body( $request ), true );
			$access_token = dozentlms_arr_get( $request, 'access_token' );

			if ( ! empty( $access_token ) ) {
				$http_args = array(
					'timeout' => 15,
					'headers' => [
						'Authorization' => 'Bearer ' . $access_token,
					],
				);

				$fields           = implode( ',', [ 'id', 'name', 'email', 'family_name', 'given_name', 'picture' ] );
				$request_userinfo = wp_remote_get( "https://www.googleapis.com/oauth2/v2/userinfo?fields=" . $fields,
					$http_args );
				$request_userinfo = json_decode( wp_remote_retrieve_body( $request_userinfo ), true );

				$social_user_id = dozentlms_arr_get( $request_userinfo, 'id' );
				if ( ! empty( $social_user_id ) ) {
					$name  = dozentlms_arr_get( $request_userinfo, 'name' );
					$email = dozentlms_arr_get( $request_userinfo, 'email' );

					$user_data = [
						'social_user_id' => $social_user_id,
						'provider'       => 'google',
						'name'           => $name,
						'email'          => $email,
					];

					$this->create_or_register_user( $user_data );
				}
			}

		}
	}

	public function create_or_register_user( $user ) {
		$username = $this->generate_username( $user );

		$full_name_arr = (array) explode( ' ', $user['name'] );
		$first_name    = array_shift( $full_name_arr );
		$last_name     = '';
		if ( is_array( $full_name_arr ) && count( $full_name_arr ) ) {
			$last_name = implode( ' ', $full_name_arr );
		}

		$userdata = apply_filters( 'dozentlms_user_register_data', [
			'user_login' => $username,
			'first_name' => $first_name,
			'last_name'  => $last_name,
			'role'       => 'subscriber',
			'user_pass'  => wp_generate_password(),
		] );

		$user_id = false;

		if ( ! empty( $user['email'] ) ) {
			$userdata['user_email'] = $user['email'];
			$user_id                = email_exists( $user['email'] );
		}

		if ( ! $user_id ) {
			//User is not exists, create one
			$user_id = wp_insert_user( $userdata );
		}

		if ( ! is_wp_error( $user_id ) ) {
			$wp_user = get_user_by( 'id', $user_id );
			if ( $wp_user ) {
				$social_user_id = dozentlms_arr_get( $user, 'social_user_id' );
				$provider       = dozentlms_arr_get( $user, 'provider' );
				update_user_meta( $user_id, 'social_login_provider', $provider );
				update_user_meta( $user_id, 'social_user_id', $social_user_id );

				wp_set_current_user( $user_id, $user->user_login );
				wp_set_auth_cookie( $user_id );
			}
		}

		wp_redirect( dozentlms_dashboard_link() );
		exit();
	}


	private function generate_username( $user ) {
		$username = '';
		if ( ! empty( $user['name'] ) ) {
			$username = $this->sanitize_username( trim( $user['name'] ) );
		}

		if ( ! validate_username( $username ) && ! empty( $user['email'] ) ) {
			// use email
			$email = explode( '@', $user['email'] );
			if ( validate_username( $email[0] ) ) {
				$username = $this->sanitize_username( $email[0] );
			}
		}

		// User name can't be on the blacklist or empty
		$illegal_names = (array) get_site_option( 'illegal_names' );
		if ( empty( $username ) || in_array( $username, $illegal_names ) ) {
			// we used all our options to generate a nice username. Use id instead
			$username = 'fb_user_' . $user['id'];
		}

		return $username;
	}

	private function sanitize_username( $username ) {
		return sanitize_title( str_replace( '_', '-', sanitize_user( $username ) ) );
	}

}

dozentlms_addon_register( 'DozentLMS_Addon_Social_Login' );