<?php

namespace DozentLMS\Admin;

class Installations {

	public static function instance() {
		static $instance = null;

		// Only run these methods if they haven't been run previously
		if ( null === $instance ) {
			$instance = new self();

			$version = get_option( 'dozentlms_version' );
			if ( ! $version ) {
				update_option( 'dozentlms_activation_time', current_time( 'timestamp' ) );
				$instance->add_roles();
				$instance->add_required_pages();
			}
			update_option( 'dozentlms_version', DOZENTLMS_VERSION );
		}

		// Always return the instance
		return $instance;
	}

	public function add_roles() {
		add_role( 'manage_dozentlms', 'Manage DozentLMS', [ 'read' => true, 'level_0' => true ] );
		add_role( 'dozentlms_instructor', __( 'DozentLMS Instructor', 'dozent-lms' ), [ 'dozentlms_instructor', 'edit_posts' ] );

		//Adding instructor capabilities to administrator role
		$role = get_role( 'administrator' );

		if ( ! $role->has_cap( 'manage_dozentlms' ) ) {
			$role->add_cap( 'manage_dozentlms' );
		}

		if ( ! $role->has_cap( 'dozentlms_instructor' ) ) {
			$role->add_cap( 'dozentlms_instructor' );
		}

		$current_user = wp_get_current_user();
		$current_user->add_role( 'dozentlms_instructor' );
	}

	public function add_required_pages() {
		$raw_settings_arr = get_option( 'dozentlms_settings' );

		$get_dashboard_page_id = ! empty( $raw_settings_arr['dashboard_page_id'] )
			? $raw_settings_arr['dashboard_page_id'] : '';
		$create_dashboard_page = false;
		$create_login_page     = false;

		/**
		 * Create Dashboard Page
		 */
		if ( $get_dashboard_page_id ) {
			$dashboard = get_post( $get_dashboard_page_id );
			if ( empty( $dashboard->post_type ) || 'publish' !== $dashboard->post_type ) {
				$create_dashboard_page = true;
			}
		} else {
			$create_dashboard_page = true;
		}

		if ( $create_dashboard_page ) {
			$dashboardPageArgs                     = [
				'post_title'  => __( 'Dashboard', 'dozent-lms' ),
				'post_type'   => 'page',
				'post_status' => 'publish'
			];
			$dashboardPageID                       = wp_insert_post( $dashboardPageArgs );
			$raw_settings_arr['dashboard_page_id'] = $dashboardPageID;
		}

		/**
		 * Create Login Page
		 */
		$get_login_page_id = ! empty( $raw_settings_arr['login_page_id'] ) ? $raw_settings_arr['login_page_id'] : '';
		if ( $get_login_page_id ) {
			$login = get_post( $get_login_page_id );
			if ( empty( $login->post_type ) || 'publish' !== $login->post_type ) {
				$create_login_page = true;
			}
		} else {
			$create_login_page = true;
		}

		if ( $create_login_page ) {
			$dashboardPageArgs                 = array(
				'post_title'  => __( 'Login', 'dozent-lms' ),
				'post_type'   => 'page',
				'post_status' => 'publish',
			);
			$loginPageID                       = wp_insert_post( $dashboardPageArgs );
			$raw_settings_arr['login_page_id'] = $loginPageID;
		}

		update_option( 'dozentlms_settings', $raw_settings_arr );
	}

}