<?php

namespace DozentLMS\Admin;

class Post_Types_Register {

	function __construct() {

		add_action( 'init', [ $this, 'register_course_post_type' ] );
		add_action( 'init', [ $this, 'register_categories' ] );
		add_action( 'init', [ $this, 'register_lecture_post_type' ] );
		add_action( 'init', [ $this, 'register_post_status' ] );

		return $this;
	}


	function register_course_post_type() {
		$labels = array(
			'name'                  => _x( 'Courses', 'Post type general name', 'dozent-lms' ),
			'singular_name'         => _x( 'Course', 'Post type singular name', 'dozent-lms' ),
			'menu_name'             => _x( 'Courses', 'Admin Menu text', 'dozent-lms' ),
			'name_admin_bar'        => _x( 'Course', 'Add New on Toolbar', 'dozent-lms' ),
			'add_new'               => __( 'Add New', 'dozent-lms' ),
			'add_new_item'          => __( 'Add New Course', 'dozent-lms' ),
			'new_item'              => __( 'New Course', 'dozent-lms' ),
			'edit_item'             => __( 'Edit Course', 'dozent-lms' ),
			'view_item'             => __( 'View Course', 'dozent-lms' ),
			'all_items'             => __( 'All Courses', 'dozent-lms' ),
			'search_items'          => __( 'Search Courses', 'dozent-lms' ),
			'parent_item_colon'     => __( 'Parent Courses:', 'dozent-lms' ),
			'not_found'             => __( 'No courses found.', 'dozent-lms' ),
			'not_found_in_trash'    => __( 'No courses found in Trash.', 'dozent-lms' ),
			'featured_image'        => _x( 'Course Cover Image',
				'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'set_featured_image'    => _x( 'Set cover image',
				'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'remove_featured_image' => _x( 'Remove cover image',
				'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'use_featured_image'    => _x( 'Use as cover image',
				'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'archives'              => _x( 'Course archives',
				'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'dozent-lms' ),
			'insert_into_item'      => _x( 'Insert into course',
				'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4',
				'dozent-lms' ),
			'uploaded_to_this_item' => _x( 'Uploaded to this course',
				'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4',
				'dozent-lms' ),
			'filter_items_list'     => _x( 'Filter courses list',
				'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4',
				'dozent-lms' ),
			'items_list_navigation' => _x( 'Courses list navigation',
				'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Pages list navigation”. Added in 4.4',
				'dozent-lms' ),
			'items_list'            => _x( 'Courses list',
				'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4',
				'dozent-lms' ),
		);

		$course_slug = dozentlms_get_setting( 'course_base_slug', 'courses' );
		if ( empty( $course_slug ) ) {
			$course_slug = 'courses';
		}

		$args = array(
			'labels'             => $labels,
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => 'dozentlms',
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $course_slug ),
			'capability_type'    => 'course',
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => null,
			'supports'           => array( 'title', 'editor', 'author', 'thumbnail', 'excerpt' ),
			'capabilities'       => array(
				'edit_post'          => 'dozentlms_instructor',
				'read_post'          => 'dozentlms_instructor',
				'delete_post'        => 'dozentlms_instructor',
				'edit_posts'         => 'dozentlms_instructor',
				'edit_others_posts'  => 'dozentlms_instructor',
				'publish_posts'      => 'dozentlms_instructor',
				'read_private_posts' => 'dozentlms_instructor',
				'create_posts'       => 'dozentlms_instructor',
			),
		);

		register_post_type( 'dozentlms_course', $args );
	}


	/**
	 * Source: WPDocs - https://developer.wordpress.org/reference/functions/register_taxonomy/
	 */

	public function register_categories() {
		$labels = [
			'name'                       => __( 'Course Categories', 'dozent-lms' ),
			'singular_name'              => __( 'Course Category', 'dozent-lms' ),
			'search_items'               => __( 'Search Course Categories', 'dozent-lms' ),
			'popular_items'              => __( 'Popular Course Categories', 'dozent-lms' ),
			'all_items'                  => __( 'All Course Categories', 'dozent-lms' ),
			'parent_item'                => null,
			'parent_item_colon'          => null,
			'edit_item'                  => __( 'Edit Course Category', 'dozent-lms' ),
			'update_item'                => __( 'Update Course Category', 'dozent-lms' ),
			'add_new_item'               => __( 'Add New Course Category', 'dozent-lms' ),
			'new_item_name'              => __( 'New Course Category Name', 'dozent-lms' ),
			'separate_items_with_commas' => __( 'Separate course categories with commas', 'dozent-lms' ),
			'add_or_remove_items'        => __( 'Add or remove course categories', 'dozent-lms' ),
			'choose_from_most_used'      => __( 'Choose from the most used course categories', 'dozent-lms' ),
			'not_found'                  => __( 'No course categories found.', 'dozent-lms' ),
			'menu_name'                  => __( 'Course Category', 'dozent-lms' ),
		];

		$slug = apply_filters( 'dozent_course_category_base',
			dozentlms_get_setting( 'category_base_slug', 'course-category' ) );
		if ( empty( $slug ) ) {
			$slug = 'course-category';
		}

		$args = [
			'hierarchical'          => true,
			'labels'                => $labels,
			'show_ui'               => true,
			'show_admin_column'     => true,
			'update_count_callback' => '_update_post_term_count',
			'query_var'             => true,
			'show_in_rest'          => true,
			'rewrite'               => [ 'slug' => $slug ],
		];

		register_taxonomy( 'course_category', 'dozentlms_course', $args );
	}


	function register_lecture_post_type() {
		$labels = array(
			'name'                  => _x( 'Lectures', 'Post type general name', 'dozent-lms' ),
			'singular_name'         => _x( 'Lecture', 'Post type singular name', 'dozent-lms' ),
			'menu_name'             => _x( 'Lectures', 'Admin Menu text', 'dozent-lms' ),
			'name_admin_bar'        => _x( 'Lecture', 'Add New on Toolbar', 'dozent-lms' ),
			'add_new'               => __( 'Add New', 'dozent-lms' ),
			'add_new_item'          => __( 'Add New Lecture', 'dozent-lms' ),
			'new_item'              => __( 'New Lecture', 'dozent-lms' ),
			'edit_item'             => __( 'Edit Lecture', 'dozent-lms' ),
			'view_item'             => __( 'View Lecture', 'dozent-lms' ),
			'all_items'             => __( 'All Lectures', 'dozent-lms' ),
			'search_items'          => __( 'Search Lectures', 'dozent-lms' ),
			'parent_item_colon'     => __( 'Parent Lectures:', 'dozent-lms' ),
			'not_found'             => __( 'No lectures found.', 'dozent-lms' ),
			'not_found_in_trash'    => __( 'No lectures found in Trash.', 'dozent-lms' ),
			'featured_image'        => _x( 'Lecture Cover Image',
				'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'set_featured_image'    => _x( 'Set cover image',
				'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'remove_featured_image' => _x( 'Remove cover image',
				'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
			'use_featured_image'    => _x( 'Use as cover image',
				'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'dozent-lms' ),
		);

		$lecture_slug = dozentlms_get_setting( 'lecture_base_slug', 'lecture' );
		if ( empty( $lecture_slug ) ) {
			$lecture_slug = 'lecture';
		}

		$args = array(
			'labels'             => $labels,
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => false,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $lecture_slug ),
			'capability_type'    => 'post',
			'has_archive'        => false,
			'hierarchical'       => false,
			'menu_position'      => null,
			'supports'           => array( 'title', 'editor', 'thumbnail' ),
			'capabilities'       => array(
				'edit_post'          => 'dozentlms_instructor',
				'read_post'          => 'dozentlms_instructor',
				'delete_post'        => 'dozentlms_instructor',
				'edit_posts'         => 'dozentlms_instructor',
				'edit_others_posts'  => 'dozentlms_instructor',
				'publish_posts'      => 'dozentlms_instructor',
				'read_private_posts' => 'dozentlms_instructor',
				'create_posts'       => 'dozentlms_instructor',
			),
		);

		register_post_type( 'dlms_lecture', $args );
	}

	public function register_post_status() {
		foreach ( dozentlms_enrollment_statuses() as $status => $status_value ) {
			register_post_status( $status, $status_value );
		}

		register_post_status(
			'draft_course',
			array(
				'label'                  => __( 'Draft Course', 'dozent-lms' ),
				'protected'              => true,
				'_builtin'               => true, /* internal use only. */
				'show_in_admin_all_list' => false,
				/* translators: %s: Number of draft posts. */
				'label_count'            => _n_noop(
					'Course Draft <span class="count">(%s)</span>',
					'Course Drafts <span class="count">(%s)</span>',
					'dozent-lms'
				),
				'date_floating'          => true,
			)
		);
	}

}