<?php

namespace DozentLMS\Admin;

defined( 'ABSPATH' ) || exit;

use DozentLMS\Core\Settings\Settings;

class Register_Menu {

	function __construct() {
		add_action( 'admin_menu', [ $this, 'register_admin_menu' ] );
		add_action( 'admin_bar_menu', [ $this, 'admin_bar_item' ], 999 );
		add_action( 'admin_init', [ $this, 'go_external_url' ] );
	}

	public function register_admin_menu() {
		add_menu_page( 'DozentLMS', 'DozentLMS', 'dozentlms_instructor', 'dozentlms', null,
			'dashicons-welcome-learn-more',
			4 );

		do_action( 'dozentlms_admin_menu/before' );

		add_submenu_page( 'dozentlms', __( 'Categories', 'dozent-lms' ), __( 'Categories', 'dozent-lms' ),
			'manage_dozentlms', 'edit-tags.php?taxonomy=course_category&post_type=dozentlms_course', null );

		add_submenu_page( 'dozentlms', __( 'Instructors', 'dozent-lms' ), __( 'Instructors', 'dozent-lms' ),
			'manage_dozentlms', 'dozentlms-instructors', [ $this, 'instructors' ] );


		add_submenu_page( 'dozentlms', __( 'Add-Ons', 'dozent-lms' ), __( 'Add-Ons', 'dozent-lms' ), 'manage_dozentlms', 'dozentlms-addons', [ $this, 'addons' ] );

		add_submenu_page( 'dozentlms', __( 'Settings', 'dozent-lms' ), __( 'Settings', 'dozent-lms' ),
			'manage_dozentlms', 'dozentlms-settings', [ $this, 'settings' ] );


		do_action( 'dozentlms_admin_menu/after' );

		add_submenu_page( 'dozentlms', __( 'Frontend Dashboard', 'dozent-lms' ),
			__( 'Frontend Dashboard', 'dozent-lms' ), 'dozentlms_instructor', 'dozentlms-frontend-dashboard',
			[ $this, 'go_external_url' ] );

	}

	public function instructors(){
		include DOZENTLMS_ABSPATH . '/core/user/instructors-page.php';
	}

	public function addons(){
		include DOZENTLMS_ABSPATH . '/addons/list-page.php';
	}

	public function settings() {
		$settings = new Settings();
		$settings->panel();
	}

	function admin_bar_item( \WP_Admin_Bar $admin_bar ) {
		if ( ! dozentlms_is_syllabus_singular() || ! current_user_can( 'dozentlms_instructor' )
		     || ! dozentlms_is_course_instructor() ) {
			return;
		}

		$current_post_type = ucwords( str_replace( 'dozentlms_', '', get_post_type() ) );
		$menu_title        = sprintf( __( "Edit %s", 'dozent-lms' ), $current_post_type );
		$post_id           = get_the_ID();

		$admin_bar->add_menu( array(
			'id'     => 'course-item-edit',
			'parent' => null,
			'group'  => null,
			'title'  => $menu_title,
			'href'   => admin_url( "post.php?post={$post_id}&action=edit" ),
			'meta'   => [
				'title' => $menu_title, //This title will show on hover
			]
		) );
	}


	public function go_external_url() {
		if ( empty( $_GET['page'] ) ) {
			return;
		}

		if ( 'dozentlms-frontend-dashboard' === dozentlms_get_var( 'page' ) ) {
			wp_redirect( dozentlms_dashboard_link() );
			exit();
		}
	}

}