<?php

/**
 * Form Request processing
 */

namespace DozentLMS\Core;

class Auth {

	function __construct() {
		add_action( 'wp_ajax_nopriv_dlms_auth_login', [ $this, 'auth_login' ] );
		add_action( 'wp_ajax_nopriv_dlms_auth_register', [ $this, 'auth_register' ] );
		add_action( 'wp_ajax_nopriv_dlms_auth_lostpassword', [ $this, 'auth_lostpassword' ] );
	}

	public function auth_login() {
		$username = dozentlms_request_text( 'username' );
		$password = dozentlms_request_text( 'password' );

		try {
			/**
			 * TODO: Add Multisite Supports...
			 */

			$credential = array(
				'user_login'    => trim( wp_unslash( $username ) ),
				'user_password' => $password,
				'remember'      => isset( $_POST['rememberme'] ),
				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			);

			$user = wp_signon( $credential, is_ssl() );

			if ( is_wp_error( $user ) ) {
				wp_send_json_error( [
					'message' => sprintf( __( ' %s Error: %s Incorrect username, E-Mail or password', 'dozent-lms' ),
						'<strong>', '</strong>' )
				] );

			} else {

				$response_args = [];
				$redirect = dozetnlms_get_redirect_to();
				if ( ! empty( $redirect ) ) {
					$response_args[ 'redirect' ] = $redirect;
				}

				wp_send_json_success( $response_args );
			}
		} catch ( \Exception $e ) {
			wp_send_json_error( [ 'message' => $e->getMessage() ] );
		}

		wp_send_json_success();
	}

	public function auth_register() {
		$fullname = dozentlms_request_text( 'fullname' );
		$username = dozentlms_request_text( 'username' );
		$email    = dozentlms_request_text( 'email' );
		$password = dozentlms_request_text( 'password' );
		$is_instructor = isset( $_POST[ '_create_instructor_account' ] ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized

		$full_name_arr = (array) explode( ' ', $fullname );
		$first_name    = array_shift( $full_name_arr );
		$last_name     = '';
		if ( is_array( $full_name_arr ) && count( $full_name_arr ) ) {
			$last_name = implode( ' ', $full_name_arr );
		}

		$userdata = apply_filters( 'dozentlms_auth_register_args', [
			'user_login' => $username,
			'user_email' => $email,
			'first_name' => $first_name,
			'last_name'  => $last_name,
			'role'       => 'subscriber',
			'user_pass'  => $password,
		] );

		$user = wp_insert_user( $userdata );

		if ( ! is_wp_error( $user ) ) {
			if ( $is_instructor ) {
				dozentlms_become_instructor( $user );
			}

			$message
				= sprintf( __( ' %s Success: %s You have successfully registered, log in to your account using your credential',
				'dozent-lms' ), '<strong>', '</strong>' );
			wp_send_json_success( [ 'message' => $message ] );
		}

		wp_send_json_error( [ 'message' => $user->get_error_messages() ] );
	}

	public function auth_lostpassword() {
		$username = dozentlms_request_text( 'lostpasasword_username' );
		$results  = retrieve_password( $username );

		if ( true === $results ) {
			wp_send_json_success( [ 'message' => __( 'A password reset link was emailed to you.', 'dozent-lms' ) ] );
		} else {
			wp_send_json_error( [ 'message' => $results->get_error_message() ] );
		}
	}

}