<?php

/**
 * Form Request processing
 */

namespace DozentLMS\Core;

class Form_Request {

	function __construct() {
		add_action( 'template_redirect', [ $this, 'complete_lecture' ] );

		//Remove any product associated with course
		add_action( 'wp_ajax_dozentlms_detach_product_from_course', [ $this, 'detach_product_from_course' ] );
		add_action( 'template_redirect', [ $this, 'finish_course' ] );

		add_action( 'init', [ $this, 'destroy_flash' ] );
	}

	public function complete_lecture() {
		if ( ! isset( $_POST['complete_lecture_id'] ) || ! is_user_logged_in() ) {
			return;
		}

		$user_id         = get_current_user_id();
		$lecture_id      = (int) dozentlms_request_text( 'complete_lecture_id' );
		$course_id       = dozentlms_course_id_by_item( $lecture_id );
		$course_progress = (array) get_user_meta( $user_id, '_dozentlms_course_progress', true );
		$course_items    = (array) dozentlms_arr_get( $course_progress, "course_items.{$course_id}" );

		$course_items[]                                = $lecture_id;
		$completed_items                               = array_filter( array_unique( $course_items ) );
		$course_progress['course_items'][ $course_id ] = $completed_items;

		//Getting Course progress in percent

		$course_contents      = dozentlms_course_contents( $course_id );
		$total_syllabus_items = 0;
		if ( is_array( $course_contents ) && count( $course_contents ) ) {
			$total_syllabus_items = count( $course_contents );
		}
		$progress_percent = 0;

		if ( is_array( $completed_items ) && count( $completed_items ) && $total_syllabus_items ) {
			$progress_percent = (int) number_format( ( count( $completed_items ) * 100 ) / $total_syllabus_items );
		}
		$course_progress['progress_percent'][ $course_id ] = $progress_percent;

		update_user_meta( $user_id, '_dozentlms_course_progress', array_filter( $course_progress ) );

		dozentlms_check_course_progress_and_mark_complete( $course_id, $user_id );

		wp_redirect( wp_get_referer() );
		exit();
	}

	/**
	 * Detach product from course pricing settings.
	 */
	public function detach_product_from_course() {
		$course_id  = dozentlms_request_text( 'course_id' );
		$product_id = dozentlms_request_text( 'product_id' );

		delete_post_meta( $course_id, '_product_id' );
		delete_post_meta( $course_id, '_product_platform' );

		do_action( 'detach_product_from_course' );

		wp_send_json_success();
	}

	public function finish_course() {
		if ( ! is_user_logged_in() || ! isset( $_POST['dozentlms-form-action'] )
		     || 'course-complete'
		        !== $_POST['dozentlms-form-action'] ) { // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			return;
		}

		$course_id = (int) dozentlms_request_text( 'dozentlms-course-id' );

		if ( ! $course_id ) {
			return;
		}

		$user_id = get_current_user_id();

		$completed_courses = get_user_meta( $user_id, '_completed_course_ids' );
		if ( ! in_array( $course_id, $completed_courses ) ) {
			add_user_meta( $user_id, '_completed_course_ids', $course_id );
		}

		wp_redirect( wp_get_referer() );
		exit();
	}


	public function destroy_flash() {
		if ( ! empty( $_COOKIE['dozentlms_session_flash']['message'] ) ) {
			setcookie( 'dozentlms_session_flash[message]' );
			setcookie( 'dozentlms_session_flash[type]' );
		}
	}

}