<?php

/**
 * Query, URL Rewrite class
 */

namespace DozentLMS\Core;

use DozentLMS\Core\User\Panel;

class Query {

	function __construct() {
		add_filter( 'query_vars', [ $this, 'add_query_vars' ] );
		add_filter( 'generate_rewrite_rules', [ $this, 'rewrite_rule' ] );
		add_filter( 'document_title_parts', [ $this, 'panel_title' ] );
	}

	public function add_query_vars( $vars ) {
		$vars[] = 'dbsegment';
		$vars[] = 'dbsegment2';
		$vars[] = 'social_login_attempt';

		return $vars;
	}

	/**
	 * @docs https://developer.wordpress.org/reference/hooks/generate_rewrite_rules/
	 *
	 * @param $wp_rewrite
	 *
	 * @return array $wp_rewrite
	 */

	public function rewrite_rule( $wp_rewrite ) {
		$index1 = $wp_rewrite->preg_index( 1 );
		$index2 = $wp_rewrite->preg_index( 2 );

		$rules = [];

		//Social Login URL
		$login_page = get_post( dozentlms_get_page_id( 'login' ) );

		if ( ! empty( $login_page->post_name ) ) {
			$rules["{$login_page->post_name}/([^/]*)"]
				= "index.php?pagename={$login_page->post_name}&social_login_attempt={$index1}";
		} else {
			$rules["social-login-attempt/([^/]*)"] = "index.php?social_login_attempt={$index1}";
		}

		$dbpage = get_post( dozentlms_get_page_id( 'dashboard' ) );
		if ( ! empty( $dbpage->post_name ) ) {
			$panel_menu_slugs = Panel::menu_slugs();
			foreach ( $panel_menu_slugs as $slug ) {
				$rules["{$dbpage->post_name}/{$slug}/?([^/]*)?$"]
					= "index.php?pagename={$dbpage->post_name}&dbsegment={$slug}&dbsegment2={$index1}";
			}
		}

		$wp_rewrite->rules = $rules + $wp_rewrite->rules;

		return $wp_rewrite->rules;
	}

	public function panel_title( $title ) {
		if ( dozentlms_is_frontend_dashboard() ) {
			global $dashboard_raw_menu_items;
			$dbsegment       = get_query_var( 'dbsegment' );
			$dbsegment_title = dozentlms_arr_get( $dashboard_raw_menu_items, $dbsegment . '.menu_title' );

			if ( ! empty( $dbsegment_title ) ) {
				$sep            = apply_filters( 'document_title_separator', '-' );
				$title['title'] = " $dbsegment_title {$sep} {$title['title']} ";
			}
		}

		return $title;
	}

}