<?php

namespace DozentLMS\Core\Course;

class Access {

	public static function instance() {
		static $instance = null;

		if ( null === $instance ) {
			$instance = new self();
		}

		return $instance;
	}

	public function __construct() {
		add_action( 'template_redirect', [ $this, 'enroll_request' ] );
		add_action( 'template_redirect', [ $this, 'enroll_from_url_var' ] );
	}


	public function enroll_request() {
		$course_id = (int) dozentlms_request_text( 'dlms_enroll_course_id' );
		$user_id   = get_current_user_id();

		if ( $course_id ) {
			$this->check_and_redirect_to_login( dozentlms_course_start_url( $course_id ) );

			if ( dozentlms_is_course_free( $course_id ) ) {
				$this->free_course_enroll( $course_id, $user_id );
			} elseif ( dozentlms_is_course_closed( $course_id ) ) {
				do_action( 'dozentlms_closed_course_enroll', $course_id, $user_id );
			}
		}
	}

	public function free_course_enroll( $course_id, $user_id ) {
		if ( ! dozentlms_enrolled( $course_id, $user_id ) ) {
			dozentlms_enroll_course( $course_id, $user_id );
		}

		$redirect_to = dozentlms_course_start_url( $course_id );
		if ( empty( $redirect_to ) ) {
			$redirect_to = get_the_permalink( $course_id );
		}

		wp_redirect( $redirect_to );
		exit();
	}

	public function check_and_redirect_to_login( $redirect_to = '' ) {
		if ( ! is_user_logged_in() ) {
			$login_url = dozentlms_get_login_url();

			if ( ! empty( $redirect_to ) ) {
				dozentlms_set_redirect_to( $redirect_to );
			}

			wp_redirect( $login_url );
			exit();
		}
	}

	public function enroll_from_url_var(){
		$course_id = (int) dozentlms_get_var( 'course_id' );
		$do_enroll = (bool) dozentlms_get_var( 'do_enroll' );

		if ( ! is_user_logged_in() || ! $do_enroll || empty( $course_id ) ) {
			return;
		}

		$access_type = dozentlms_course_access_type( $course_id );
		$user_id = get_current_user_id();

		if ( 'free' === $access_type ) {
			$this->free_course_enroll( $course_id, $user_id );
		}

	}

}