<?php

namespace DozentLMS\Core\Course;

class Course_Data {

	public static function instance() {
		static $instance = null;

		if ( null === $instance ) {
			$instance = new self();
		}

		return $instance;
	}

	public function __construct() {
		add_action( 'dozentlms/course/metabox/before', [ $this, 'course_data' ] );

		add_action( 'save_post_dozentlms_course', [ $this, 'save_coursedata' ] );
		add_action( 'dozentlms/course_data/before_form/course_builder', [ $this, 'course_builder' ] );
		add_action( 'dozentlms/course_data/before_form/intended_learners', [ $this, 'intended_learners' ] );
		add_action( 'dozentlms/course_data/before_form/pricing', [ $this, 'coursedata_pricing' ] );
		add_action( 'dozentlms/course_data/before_form/promo_video', [ $this, 'coursedata_promo_video' ] );

		//Admin Course List Data
		add_filter( 'manage_dozentlms_course_posts_columns', [ $this, 'course_info_column' ], 20 );
		add_action( 'manage_dozentlms_course_posts_custom_column', [ $this, 'render_course_info_column' ], 10, 2 );
	}

	public function course_data() {
		add_meta_box( 'dozentlms-course-data', __( 'Course Data', 'dozent-lms' ), [ $this, 'coursedata_box' ],
			'dozentlms_course', 'advanced', 'high' );
	}

	public function coursedata_box() {
		include DOZENTLMS_ABSPATH . '/core/course/data.php';
	}

	public function save_coursedata( $courseID ) {
		$course_edit_screen = dozentlms_request_text( 'course_edit_screen' );
		if ( empty( $course_edit_screen ) || ! in_array( $course_edit_screen, [ 'admin', 'frontend' ] ) ) {
			return;
		}

		// Dont' save meta boxes for revisions or autosaves.
		if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || is_int( wp_is_post_revision( $courseID ) )
		     || is_int( wp_is_post_autosave( $courseID ) ) ) {
			return;
		}

		$course_data = dozentlms_request_arr( 'course_data' );
		update_post_meta( $courseID, '_course_data', $course_data );

		//Access Type (Pricing)
		$course_access_type = dozentlms_request_text( 'course_access_type' );
		update_post_meta( $courseID, '_course_access_type', $course_access_type );

		//Promo Video
		$_video = dozentlms_request_arr( '_video' );
		update_post_meta( $courseID, '_video', $_video );

		//Intended Learners
		$learning_goal         = dozentlms_request_textarea( 'learning_goal' );
		$learning_requirements = dozentlms_request_textarea( 'learning_requirements' );
		$targeted_students     = dozentlms_request_textarea( 'targeted_students' );

		update_post_meta( $courseID, '_learning_goal', $learning_goal );
		update_post_meta( $courseID, '_learning_requirements', $learning_requirements );
		update_post_meta( $courseID, '_targeted_students', $targeted_students );

		//Sync Course
		dozentlms_sync_course( $courseID );

		do_action( 'dozentlms_save_coursedata', $courseID );
	}

	/**
	 * @since DozentLMS 1.1.7
	 */

	public function course_builder(){
		require DOZENTLMS_ABSPATH . '/core/course/coursebuilder.php';
	}

	public function intended_learners(){
		include DOZENTLMS_ABSPATH . '/core/course/data-panel/intended-learners.php';
	}

	public function coursedata_pricing() {
		include DOZENTLMS_ABSPATH . '/core/course/data-panel/pricing-data.php';
	}

	public function coursedata_promo_video() {
		include DOZENTLMS_ABSPATH . '/core/course/data-panel/promo-video.php';
	}


	public function course_info_column( $columns ) {
		$date_column = dozentlms_arr_get( $columns, 'date' );
		if ( $date_column ) {
			unset( $columns['date'] );
		}

		if ( isset( $columns['author'] ) ) {
			unset( $columns['author'] );
		}

		$columns['course_info']  = __( 'Course Info', 'dozent-lms' );
		$columns['course_price'] = __( 'Price', 'dozent-lms' );

		if ( $date_column ) {
			$columns['date'] = $date_column;
		}

		return $columns;
	}

	public function render_course_info_column( $column, $post_id ) {
		if ( 'course_info' === $column ) {
			$lecture_count = (int) get_post_meta( $post_id, '_total_lectures', true );
			echo '<p class="course-list-info-meta"> ' . sprintf( _n( '%d Lecture', '%d Lectures', $lecture_count, 'dozent-lms' ), $lecture_count ) . ' </p>';
		}

		if ( 'course_price' === $column ) {
			dozentlms_course_price( $post_id );
		}
	}

}