<?php
require DOZENTLMS_ABSPATH . '/core/course/card-hooks.php';

function dozentlms_get_course_price_raw( $course = null ) {
	$course = get_post( $course );

	return apply_filters( 'dozentlms_course_raw_price', 0, $course );
}

function dozentlms_course_price( $course = null, $echo = true ) {
	$course = get_post( $course );
	$price = dozentlms_get_course_price_raw( $course );

	if ( ! $price ) {
		$price  = apply_filters( 'dozentlms/course_price/free_text', __( 'Free', 'dozent-lms' ) );
	}

	$price  = apply_filters( 'dozentlms_course_price', $price, $course );

	$priceIcon = '';
	if ( dozentlms_is_course_free() ) {
		$priceIcon = '<i class="lmsicon-lock"></i>';
	} elseif ( dozentlms_is_course_public() ) {
		$priceIcon = '<i class="lmsicon-earth"></i>';
	}


	$priceHTML = "<div class='dlms-price-html'> {$priceIcon} {$price} </div>";

	$priceHTML = apply_filters( 'dozentlms_course_price_html', $priceHTML, $price, $course );

	if ( $echo ) {
		echo $priceHTML;
	}

	return $priceHTML;
}

function dozentlms_next_module_order( $course_ID ) {
	global $wpdb;

	$next_order = $wpdb->get_var( $wpdb->prepare( "SELECT MAX(menu_order) + 1 FROM {$wpdb->posts} WHERE post_parent = %d ;", $course_ID ) );

	return intval( $next_order );
}

function dozentlms_next_content_order_id( $course_id ) {
	global $wpdb;

	$max_order = (int) $wpdb->get_var( $wpdb->prepare( "SELECT 
	MAX(contents.menu_order) 
	FROM {$wpdb->posts} AS contents
	WHERE contents.post_parent 
	IN( SELECT GROUP_CONCAT(cmodule.ID) 
		FROM {$wpdb->posts} AS cmodule 
		WHERE ( cmodule.post_parent = %d 
		AND cmodule.post_type = 'dozentlms_module' ) 
		HAVING COUNT( cmodule.ID ) > 0 ) ;", $course_id )
	);

	return $max_order + 1;
}

function dozentlms_get_modules( $course ) {
	global $wpdb;

	$course_ID = dozentlms_get_the_post_ID( $course );

	$modules
		= $wpdb->get_results( "SELECT * FROM {$wpdb->posts} WHERE post_parent = {$course_ID} AND post_type = 'dozentlms_module' order by menu_order asc;" );

	return $modules;
}

function dozentlms_course_contents_by_module( $module = 0 ) {
	$module_ID = dozentlms_get_the_post_ID( $module );

	$content_post_types = apply_filters( 'dozentlms_course_contents_post_types',
		[ 'dlms_lecture', 'dlms_quiz', 'dlms_assignment' ] );

	$args  = [
		'post_type'      => $content_post_types,
		'post_parent'    => $module_ID,
		'posts_per_page' => -1,
		'orderby'        => 'menu_order',
		'order'          => 'ASC',
	];
	$query = new \WP_Query( $args );

	return $query->posts;
}

/**
 * Print icon according to the course content type
 *
 * @since DozentLMS 1.1.5
 *
 * @param  null  $content
 */

function dozentlms_course_content_icon( $content = null ) {
	$content = get_post( $content );

	$icon_html = "<i class='lmsicon-file'></i>";
	if ( $content ) {

		if ( 'dlms_lecture' === $content->post_type ) {
			$video = dozentlms_get_course_video( $content );
			if ( ! empty( $video ) ) {
				$icon_html = "<i class='lmsicon-video'></i>";
			}
		}

	}

	$icon_html = apply_filters( 'dozentlms_course_content_icon', $icon_html, $content );

	echo trim( $icon_html ) . '&nbsp;';
}

function dozentlms_the_course( $display = 'card' ) {
	dozentlms_locate_template( 'course/card', true );
}

/**
 * Get the course attached instructors plain name
 *
 * @since DozentLMS 1.0.0
 *
 * @param  null  $course
 *
 * @return string
 */

function dozentlms_course_tagged_instructors( $course = null ){
	$course = get_post( $course );
	return get_the_author_meta( 'display_name', $course->post_author );
}

function dozentlms_excerpt( $course = null, $echo = true ) {
	$course = get_post( $course );

	$excerpt = esc_html( strip_tags( $course->post_excerpt ) );

	if ( empty( $excerpt ) ) {
		$excerpt  = esc_html( strip_tags( $course->post_content ) );
		$excerptA = explode( " ", str_replace( "  ", " ", $excerpt ) );
		if ( count( $excerptA ) > 55 ) {
			$excerptA = array_slice( $excerptA, 0, 55 );
		}
		$excerpt = implode( " ", $excerptA );
	}

	$excerpt = apply_filters( 'dozentlms_excerpt', $excerpt );

	if ( $echo ) {
		echo $excerpt;
	}

	return $excerpt;
}

function dozentlms_course_contents( $course = null ) {
	global $wpdb;

	$course = get_post( $course );

	if ( empty( $course ) ) {
		return [];
	}

	$course_contents = wp_cache_get( $course->ID, 'dozentlms_course_contents' );

	if ( empty( $course_contents ) ) {
		$course_contents = $wpdb->get_results( "SELECT contents.* 
				FROM {$wpdb->posts} modules
				INNER JOIN {$wpdb->posts} contents ON modules.ID = contents.post_parent 
				WHERE modules.post_parent = {$course->ID} 
				AND contents.post_status = 'publish' 
				ORDER BY modules.menu_order ASC, contents.menu_order ASC;" );

		wp_cache_add( $course->ID, $course_contents, 'dozentlms_course_contents' );
	}

	return apply_filters( 'dozentlms_course_contents', $course_contents, $course );
}

function dozentlms_sync_course( $course = null ) {
	$course = get_post( $course );
	wp_cache_delete( $course->ID, 'dozentlms_course_contents' );

	$course_contents         = dozentlms_get_course_syllabus_data( $course );
	$lectures_count          = 0;
	$module_count            = dozentlms_arr_count( $course_contents );
	$extracted_content_items = wp_list_pluck( $course_contents, 'items' );
	$content_items           = array_values( call_user_func_array( 'array_merge', $extracted_content_items ) );
	$content_items_count     = dozentlms_arr_count( $content_items );

	$run_time = 0;
	foreach ( $content_items as $item ) {
		if ( 'dlms_lecture' === $item->post_type ) {
			$lectures_count ++;

			$lecture_video = get_post_meta( $item->ID, '_video', true );

			if ( is_array( $lecture_video ) && count( $lecture_video ) ) {
				$source = dozentlms_arr_get( $lecture_video, 'source' );

				//Get the duration from uploaded video file
				if ( 'upload' === $source && ( ! empty( $lecture_video['upload']['video_id'] ) ) ) {
					$video_metadata = get_post_meta( $lecture_video['upload']['video_id'], '_wp_attachment_metadata', true );
					$length_format = dozentlms_arr_get( $video_metadata, 'length_formatted' );

					$video_time = (int) dozentlms_duration_to_time( $length_format );
					$run_time = $run_time + $video_time;
				} else{

					$video_duration_arr = dozentlms_arr_get( $lecture_video, 'runtime' );
					$video_duration = implode( ':', $video_duration_arr );
					$converted_runtime = (int) dozentlms_duration_to_time( $video_duration );

					$run_time = $run_time + $converted_runtime;
				}

			}

		}
	}

	//TODO: Add total quiz, assignments too
	update_post_meta( $course->ID, '_total_modules', $module_count );
	update_post_meta( $course->ID, '_total_lectures', $lectures_count );
	update_post_meta( $course->ID, '_total_content_items', $content_items_count );
	update_post_meta( $course->ID, '_total_runtime_seconds', $run_time );
}

function dozentlms_course_start_url( $course = null ) {
	$contents = dozentlms_course_contents( $course );
	if ( empty( $contents[0] ) ) {
		return null;
	}

	return get_the_permalink( $contents[0] );
}

function dozentlms_get_course_syllabus_data( $course = null ) {
	$course  = get_post( $course );
	$modules = dozentlms_get_modules( $course );

	foreach ( $modules as $key => $module ) {

		$items        = dozentlms_course_contents_by_module( $module->ID );
		$module_stats = array_count_values( array_column( $items, 'post_type' ) );

		$modules[ $key ]->total_lectures = 0;
		$modules[ $key ]->items          = $items;

		if ( ! empty( $module_stats['dlms_lecture'] ) ) {
			$modules[ $key ]->total_lectures = $module_stats['dlms_lecture'];
		}
	}

	return $modules;
}

/**
 * Alias function of `dozentlms_get_course_syllabus_data()`, get the course contents with module
 *
 * @since DozentLMS 1.1.5
 *
 * @see dozentlms_get_course_syllabus_data();
 *
 * @param  null  $course Course ID or Object. Returned current course contents from the loop in case of null
 *
 * @return array|object|null
 */

function dozentlms_get_full_course_content( $course = null ){
	return dozentlms_get_course_syllabus_data( $course );
}

function dozentlms_course_id_by_item( $item = null ) {
	global $wpdb;

	$item = get_post( $item );

	if ( empty( $item->ID ) ) {
		return null;
	}

	$course_id = $wpdb->get_var( "SELECT post_parent 
	FROM {$wpdb->posts} 
	WHERE ID = {$item->post_parent} 
	AND post_type = 'dozentlms_module' " );

	return absint( $course_id );
}

/**
 * @param int|WP_Post|null $post   Course, Lecture ID or object. `null`, `false`, `0` and other PHP falsey
 *                                 values return the current global post inside the loop.
 *
 * @since DozentLMS 1.0.0
 *
 * @return null|array
 */

function dozentlms_get_course_video( $post = null ) {
	$post = get_post( $post );

	$video = get_post_meta( $post->ID, '_video', true );

	if ( empty( $video ) ) {
		return null;
	}

	$source = dozentlms_arr_get( $video, 'source' );
	if ( empty( $source ) || empty( $video[ $source ] ) ) {
		return null;
	}

	if ( ! empty( $video['upload']['video_id'] ) ) {
		$video['video_info'] = wp_prepare_attachment_for_js( $video['upload']['video_id'] );
	}
	if ( ! empty( $video['upload']['poster_id'] ) ) {
		$video['poster_info'] = wp_prepare_attachment_for_js( $video['upload']['poster_id'] );
	}

	return $video;
}


function dozentlms_next_previous_id( $syllabusItem = 0 ) {
	$syllabusItem = get_post( $syllabusItem );
	if ( empty( $syllabusItem->ID ) ) {
		return 0;
	}

	$course_id = dozentlms_course_id_by_item( $syllabusItem );
	$syllabus  = dozentlms_course_contents( $course_id );

	$previous_id = 0;
	$next_id     = 0;

	if ( is_array( $syllabus ) && count( $syllabus ) ) {
		$ids = wp_list_pluck( $syllabus, 'ID' );

		foreach ( $ids as $position => $value ) {
			if ( $value == $syllabusItem->ID ) {
				$previous_id = (int) dozentlms_arr_get( $ids, ( $position - 1 ) );
				$next_id     = (int) dozentlms_arr_get( $ids, ( $position + 1 ) );
				break;
			}
		}
	}

	return (object) [ 'previous_id' => $previous_id, 'next_id' => $next_id ];
}


function dozentlms_course_data_field_attrs() {
	$data = [
		'general'     => [
			'title'       => __( 'General', 'dozent-lms' ),
			'description' => __( 'Course general settings', 'dozent-lms' ),

			'form_fields' => [
				'access_expiration_days' => [
					'type'        => 'number',
					'title'       => 'Access Expiration',
					'default'     => 0,
					'description' => __( 'Number of days a student have access to this course after enrolling', 'dozent-lms' )
				],

			],

		],
		'course_builder'     => [
			'title'       => __( 'Course Builder', 'dozent-lms' ),
		],
		'intended_learners'     => [
			'title'       => __( 'Intended Learners', 'dozent-lms' ),
			'description' => __( 'By filling following descriptions, you are letting know the learners what you are offering at this course or if there are any prerequisites. So the learners can easily decide whether this course is appropriate or not.', 'dozent-lms' ),
		],
		'pricing'     => [
			'title'       => __( 'Pricing', 'dozent-lms' ),
			'description' => __( 'Set the course price. It will be displayed on the course landing page.', 'dozent-lms' ),
		],

		'promo_video' => [
			'title' => __( 'Promo Video', 'dozent-lms' )
		]
	];

	return apply_filters( 'dozentlms_course_data_field_attrs', $data );
}

function dozentlms_course_data( $name, $course_id = null, $default = false ) {
	$course = get_post( $course_id );
	if ( empty( $course ) ) {
		return false;
	}

	$data = get_post_meta( $course->ID, '_course_data', true );

	return dozentlms_arr_get( $data, $name, $default );
}

function dozentlms_course_meta( $key , $course_id = null ) {
	if ( ! $course_id ) {
		$course_id = get_the_ID();
	}

	return get_post_meta( $course_id, $key, true );
}

function dozentlms_course_pricing_types() {
	$types = [
		'public' => [
			'name'        => __( 'Public', 'dozent-lms' ),
			'description' => __( 'Anyone can access this course syllabus/contents and materials without getting log in or having an account.',
				'dozent-lms' ),
		],
		'free'   => [
			'name'        => __( 'Free', 'dozent-lms' ),
			'description' => __( 'The course is free but protected from the public. To access this course, users need to get login and enroll.',
				'dozent-lms' ),
		],
		'closed' => [
			'name'        => __( 'Closed', 'dozent-lms' ),
			'description' => __( 'Course enrollment will be via integration. Users can buy this course through shopping cart plugins. Supports WooCommerce, Easy Digital Download.',
				'dozent-lms' ),
			//'callback'  => '',
		],
	];

	return apply_filters( 'dozentlms_course_pricing_types', $types );
}

function dozentlms_course_access_type( $courseID = 0 ){
	if ( empty( $courseID ) ) {
		$courseID = get_the_ID();
	}

	$access_type = get_post_meta( $courseID, '_course_access_type', true );
	if ( empty( $access_type ) ) {
		$access_type = 'public';
	}

	return apply_filters( 'dozentlms_course_access_type', $access_type, $courseID );
}

function dozentlms_is_course_public( $course = null ) {
	$course = get_post( $course );

	return ( 'public' == dozentlms_course_access_type( $course->ID ) );
}

function dozentlms_is_course_free( $course = null ) {
	$course = get_post( $course );

	return ( 'free' == dozentlms_course_access_type( $course->ID ) );
}

function dozentlms_is_course_closed( $course = null ) {
	$course = get_post( $course );

	return ( 'closed' == dozentlms_course_access_type( $course->ID ) );
}

function dozentlms_has_course_access( $course = null, $user_id = 0 ) {
	$course = get_post( $course );

	if ( dozentlms_is_course_public( $course ) ) {
		return true;
	}

	if ( is_user_logged_in() ) {
		/**
		 * Check if the instructor of the course opened his course.
		 * if true, let him see his course contents.
		 */

		$user_id = ( $user_id ) ? $user_id : get_current_user_id();
		if ( ( $course->post_author == $user_id ) ) {
			return true;
		}

		/**
		 * Actually checking if a course has been enrolled by user.
		 */

		return dozentlms_enrolled( $course );
	}

	return false;
}

function dozentlms_enroll_course( $course = null, $user_id = 0, $args = [] ) {
	global $wpdb;

	$course  = get_post( $course );
	$user_id = ( $user_id ) ? $user_id : get_current_user_id();

	$defaults = apply_filters( 'dozentlms_enroll_course_default_args', [
		'order_id'       => null,
		'order_platform' => null,
	] );

	$r = wp_parse_args( $args, $defaults );
	extract( $r, EXTR_SKIP );

	$enroll_data = [
		'post_author' => $user_id,
		'post_date'   => current_time( 'mysql' ),
		'post_title'  => "Enrolled#{$course->ID}",
		'post_status' => "dlms-pending", //pending|active|expired|cancelled
		'post_parent' => $course->ID,
		'post_type'   => 'dlms_enrollment',
	];

	if ( dozentlms_is_course_free( $course ) ) {
		$enroll_data['post_status'] = 'dlms-active';
	}

	if ( ! empty( $order_id ) ) {
		$meta_input = [
			'_belongs_order_id' => $order_id
		];

		if ( ! empty( $order_platform ) ) {
			$meta_input['_order_platform'] = $order_platform;
		}

		$enroll_data['meta_input'] = $meta_input;
	}

	$enroll_data = apply_filters( 'dozentlms_enroll_data', $enroll_data );
	$enroll_id   = wp_insert_post( $enroll_data );

	if ( ! $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM {$wpdb->usermeta} WHERE user_id = %d AND meta_key = '_enrolled_courses' AND meta_value = %d",
		$user_id, $course->ID ) ) ) {

		add_user_meta( $user_id, '_enrolled_courses', $course->ID );
	}

	do_action( 'dozentlms/enrolled', $course->ID, $user_id, $enroll_id, $enroll_data );
}

/**
 * Determine whether a course has been enrolled by a specific user or not.
 *
 * @param int|WP_Post|null $course   Optional. Post ID or post object. `null`, `false`, `0` and other PHP falsey
 *
 * @param  int  $user_id Optional, user_id will be current user id if no pass this param.
 *
 * @return bool
 */

function dozentlms_enrolled( $course = null, $user_id = 0 ) {
	$course = get_post( $course );

	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	if ( empty( $course->ID ) ) {
		/**
		 * If no valid course found, return false.
		 */
		return apply_filters( 'dozentlms_enrolled', false, $course, $user_id, null );
	}

	$query = get_posts( [
		'author'      => $user_id,
		'post_parent' => $course->ID,
		'post_type'   => 'dlms_enrollment',
		'numberposts' => '-1',
		'post_status' => 'dlms-active',
	] );

	if ( is_array( $query ) && count( $query ) ) {
		//TODO: Check course expiry

		return apply_filters( 'dozentlms_enrolled', true, $course, $user_id, $query );
	}

	return apply_filters( 'dozentlms_enrolled', false, $course, $user_id, null );
}

function dozentlms_enrolled_courses() {
	$course_ids = get_user_meta( get_current_user_id(), '_enrolled_courses' );

	if ( empty( $course_ids ) ) {
		return null;
	}

	$queryArgs = [
		'post_type'      => 'dozentlms_course',
		'post_status'    => 'publish',
		'post__in'       => $course_ids,
		'posts_per_page' => '-1',
	];

	return new \WP_Query( $queryArgs );
}


/**
 * Get my courses query results
 * Returns Courses published or added as instructor.
 *
 * @return false|WP_Query
 */

function dozentlms_my_courses() {
	if ( ! is_user_logged_in() ) {
		return false;
	}

	$user_id     = get_current_user_id();
	$post_status = [ 'publish', 'pending', 'draft', 'private', 'draft_course' ];

	$queryArgs = [
		'author'           => $user_id,
		'post_type'        => 'dozentlms_course',
		'post_status'      => $post_status,
		'posts_per_page'   => '-1',
		'suppress_filters' => true,
		'orderby'          => 'date',
		'order'            => 'DESC',
	];

	return new \WP_Query( $queryArgs );
}

function dozentlms_course_stats( $course = null ) {
	$course = get_post( $course );

	$value = [
		'lectures_total' => 0,
	];

	$value['lectures_total'] = (int) get_post_meta( $course->ID, '_total_lectures', true );

	return (object) $value;
}

/**
 * Get the course completion progress by student
 *
 * @param  int  $course_id
 * @param  int  $user_id
 *
 * @return array
 */
function dozentlms_course_progress( $course_id = 0, $user_id = 0 ) {
	if ( ! $course_id ) {
		$course_id = get_the_ID();
	}

	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	$course_progress = (array) get_user_meta( $user_id, '_dozentlms_course_progress', true );

	$progress             = [];
	$progress['syllabus'] = (array) dozentlms_arr_get( $course_progress, "course_items.{$course_id}" );
	$percent              = dozentlms_arr_get( $course_progress, "progress_percent.{$course_id}" );
	$progress['percent']  = intval( $percent );

	return $progress;
}

function dozentlms_is_syllabus_item_completed( $item_id = null ) {
	if ( ! $item_id ) {
		$item_id = get_the_ID();
	}

	$course_id       = dozentlms_course_id_by_item( $item_id );
	$course_progress = dozentlms_course_progress( $course_id );
	$items_completed = (array) dozentlms_arr_get( $course_progress, 'syllabus' );

	return in_array( $item_id, array_filter( $items_completed ) );
}

/**
 * This function will check if the course progress has been 100%.
 * If true, then it will complete the course by itself.
 *
 * @param $course_id
 * @param  int  $user_id
 *
 * @return false|int
 */

function dozentlms_check_course_progress_and_mark_complete( $course_id, $user_id = 0 ) {
	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	$progress = dozentlms_course_progress( $course_id, $user_id );
	$percent  = dozentlms_arr_get( $progress, 'percent' );

	if ( 100 == $percent || 99 > 100 ) {
		$completed_courses = get_user_meta( $user_id, '_completed_course_ids' );
		if ( ! in_array( $course_id, $completed_courses ) ) {
			return add_user_meta( $user_id, '_completed_course_ids', $course_id );
		}
	}

	return false;
}

/**
 * Retrieves the new course link.
 * If frontend course builder addon enabled, then it will create new course url for frontend.
 *
 * @since DozentlMS 1.2.0
 *
 * @return string|void
 */

function dozentlms_new_course_link() {
	if ( ! dozentlms_addon_activated( 'frontend-course-builder' ) ) {
		return admin_url( 'post-new.php?post_type=dozentlms_course' );
	}

	return dozentlms_dashboard_link( 'create-new-course' );
}

/**
 * Retrieves the edit link for course.
 *
 * @since DozentLMS 1.0.0
 *
 * @param int|WP_Post $course      Course ID or course post object.
 *
 * @return string|void
 */

function dozentlms_course_edit_link( $course = null ) {
	$course = get_post( $course );
	if ( ! $course ) {
		return;
	}

	if ( ! dozentlms_addon_activated( 'frontend-course-builder' ) ) {
		return add_query_arg( [ 'post' => $course->ID, 'action' => 'edit' ], admin_url( 'post.php' ) );
	}

	return add_query_arg( [ 'course' => $course->ID, 'action' => 'edit' ], dozentlms_dashboard_link( 'edit-course' ) );
}

/**
 * Check if an user wishlisted a course
 *
 * @since DozentLMS 1.0.0
 *
 * @param  null  $course
 * @param  int  $user_id
 *
 * @return bool
 */
function dozentlms_wishlisted( $course = null, $user_id = 0 ) {
	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	if ( ! $user_id ) {
		return false;
	}

	$course    = get_post( $course );
	$wishlists = get_user_meta( $user_id, '_dozentlms_course_wishlist' );

	return in_array( $course->ID, $wishlists );
}

function dozentlms_wishlisted_courses( $user_id = 0 ){
	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	$wishlists = get_user_meta( $user_id, '_dozentlms_course_wishlist' );

	if ( empty( $wishlists ) ) {
		return null;
	}

	$queryArgs = [
		'post_type'      => 'dozentlms_course',
		'post_status'    => 'publish',
		'post__in'       => $wishlists,
		'posts_per_page' => '-1',
	];

	return new \WP_Query( $queryArgs );
}


/**
 * Check if a syllabus item has been completed by the student
 *
 * @since DozentLMS 1.1.2
 *
 * @param $lecture_id
 * @param $user_id
 *
 * @return bool
 */

function dozentlms_is_lecture_completed( $lecture_id, $user_id ) {
	$course_id = dozentlms_course_id_by_item( $lecture_id );

	$progress = dozentlms_course_progress( $course_id, $user_id );
	$syllabus = dozentlms_arr_get( $progress, 'syllabus' );

	return ( is_array( $syllabus ) && in_array( $lecture_id, $syllabus ) );
}

/**
 * Check if a course has been completed by student
 *
 * @since DozentLMS 1.1.2
 *
 * @param  null  $course
 * @param  int  $user_id
 *
 * @return false|int
 */

function dozentlms_is_course_completed( $course = null, $user_id = 0 ) {
	$course = get_post( $course );
	if ( ! $user_id && is_user_logged_in() ) {
		$user_id           = get_current_user_id();
		$completed_courses = get_user_meta( $user_id, '_completed_course_ids' );

		return in_array( $course->ID, $completed_courses );
	}

	return false;
}

/**
 * Dynamically retrieve the course ID from the current course single page.
 * Or any from any course syllabus item loop
 *
 * @since DozentLMS 1.1.2
 *
 * @param  null  $post
 *
 * @return int|null
 */

function dozentlms_get_course_id( $post = null ) {
	$post = get_post( $post );

	if ( 'dozentlms_course' === $post->post_type ) {
		return $post->ID;
	}

	return dozentlms_course_id_by_item( $post );
}

/**
 * Get finished courses by students
 *
 * @return WP_Query|null
 */

function dozentlms_completed_courses( $user_id = 0 ) {
	if ( ! $user_id ) {
		$user_id = get_current_user_id();
	}

	$course_ids = get_user_meta( $user_id, '_completed_course_ids' );

	if ( empty( $course_ids ) ) {
		return null;
	}

	$queryArgs = [
		'post_type'      => 'dozentlms_course',
		'post_status'    => 'publish',
		'post__in'       => $course_ids,
		'posts_per_page' => '-1',
	];

	return new \WP_Query( $queryArgs );
}

/**
 * Abstract class for Syllabus next previous link
 *
 * Class DozentLMS_Syllabus_Next_Previous_Link_Abstract
 */

class DozentLMS_Syllabus_Next_Previous_Link_Abstract {
	public $previous_id = 0;
	public $previous_link;
	public $previous_post_type_label;
	public $next_id = 0;
	public $next_link;
	public $next_post_type_label;
}

/**
 * Get syllabus next previous link data as object
 *
 * @since DozentLMS 1.1.4
 *
 * @param  null  $current_item
 *
 * @return DozentLMS_Syllabus_Next_Previous_Link_Abstract
 */

function dozentlms_get_syllabus_next_previous_link_obj( $current_item = null ) {
	$current_item = get_post( $current_item );

	$syllabus_items     = dozentlms_course_contents( dozentlms_course_id_by_item( $current_item ) );
	$syllabus_items_ids = wp_list_pluck( $syllabus_items, 'ID' );
	$current_item_key   = array_search( get_the_ID(), $syllabus_items_ids );
	$previous_item_id   = (int) dozentlms_arr_get( $syllabus_items_ids, ( $current_item_key - 1 ) );
	$next_item_id       = (int) dozentlms_arr_get( $syllabus_items_ids, ( $current_item_key + 1 ) );

	$data = new DozentLMS_Syllabus_Next_Previous_Link_Abstract();

	if ( $previous_item_id ) {
		$previous_post_type_obj = get_post_type_object( get_post_type( $previous_item_id ) );

		$data->previous_id              = $previous_item_id;
		$data->previous_link            = get_the_permalink( $previous_item_id );
		$data->previous_post_type_label = $previous_post_type_obj->labels->singular_name;
	}

	if ( $next_item_id ) {
		$next_post_type_obj = get_post_type_object( get_post_type( $previous_item_id ) );

		$data->next_id              = $next_item_id;
		$data->next_link            = get_the_permalink( $next_item_id );
		$data->next_post_type_label = $next_post_type_obj->labels->singular_name;
	}

	return $data;
}

/**
 * Filter items to filter course at the archive page
 *
 * @since DozentLMS 1.1.4
 *
 * @param  null  $filter_by
 *
 * @return array|mixed|void|null
 */

function dozentlms_course_filter_items( $filter_by = null ) {
	$items = [
		'relevance'  => __( 'Most Relevant', 'dozent-lms' ),
		'title-asc'  => __( 'Title (a-z)', 'dozent-lms' ),
		'title-desc' => __( 'Title (z-a)', 'dozent-lms' ),
		'newest'     => __( 'Newest first', 'dozent-lms' ),
		'oldest'     => __( 'Oldest first', 'dozent-lms' ),
	];

	if ( $filter_by ) {
		return dozentlms_arr_get( $items, $filter_by );
	}

	return apply_filters( 'dozentlms_course_filter_items', $items );
}

/**
 * Get a small stats about the course. Total module, lectures, etc.
 *
 * @param  null  $course Course ID or Object
 *
 * @return object
 */

function dozentlms_get_course_content_stats( $course = null ) {
	$course = get_post( $course );

	$data = [
		'total_runtime_seconds'   => 0,
		'human_readable_duration' => '',
	];

	$data['total_module']   = (int) get_post_meta( $course->ID, '_total_modules', true );
	$data['total_lectures'] = (int) get_post_meta( $course->ID, '_total_lectures', true );
	$runtime_seconds        = (int) get_post_meta( $course->ID, '_total_runtime_seconds', true );

	if ( $runtime_seconds ) {
		$data['total_runtime_seconds']   = $runtime_seconds;
		$data['human_readable_duration'] = dozentlms_human_readable_duration( $runtime_seconds, true, true, false );
	}

	return (object) $data;
}

function dozentlms_get_lecture_video_time( $lecture = null ) {
	$lecture = get_post( $lecture );

	$lecture_video = get_post_meta( $lecture->ID, '_video', true );

	$video_time = 0;

	if ( is_array( $lecture_video ) && count( $lecture_video ) ) {
		$source = dozentlms_arr_get( $lecture_video, 'source' );

		//Get the duration from uploaded video file
		if ( 'upload' === $source && ( ! empty( $lecture_video['upload']['video_id'] ) ) ) {
			$video_metadata = get_post_meta( $lecture_video['upload']['video_id'], '_wp_attachment_metadata', true );
			$length_format  = dozentlms_arr_get( $video_metadata, 'length_formatted' );
			$video_time     = (int) dozentlms_duration_to_time( $length_format );
		} else {

			$video_duration_arr = dozentlms_arr_get( $lecture_video, 'runtime' );
			$video_duration     = implode( ':', $video_duration_arr );
			$video_time         = (int) dozentlms_duration_to_time( $video_duration );
		}

	}

	return $video_time;
}

function dozentlms_frontend_course_builder() {
	echo "<div class='dlms-fcb-wrap'>";
	echo "<form action='' id='dlms-fcb-form' method='post'>";
	do_action( 'dozentlms/frontend/course/builder/area' );
	echo '</form>';
	echo '</div>';
}

/**
 * Returns whether current user can publish course directly
 *
 * @return bool
 */

function dozentlms_current_user_can_publish_course() {
	if ( dozentlms_is_administrator() ) {
		return true;
	}

	$allow_directly_publish = (bool) dozentlms_get_setting( 'allow_instructor_publish_course' );

	return ( dozentlms_is_instructor() && $allow_directly_publish );
}

/**
 * Get total lectures for a course
 *
 * @since DozentLMS 1.2.1
 *
 * @param  null  $course
 *
 * @return int
 */

function dozentlms_course_total_lectures( $course = null ) {
	$course = get_post( $course );

	return (int) get_post_meta( $course->ID, '_total_lectures', true );
}

function dozentlms_course_whats_included_items( $course = null ) {
	$course = get_post( $course );

	if ( ! dozentlms_is_course( $course ) ) {
		return [];
	}

	$items = [
		'total_lecture'                => '',
		'total_quiz'                   => '',
		'total_assignment'             => '',
		'video_length'                 => '',
		'total_downloadable_resources' => '',
		'has_lifetime_access'          => '',
		'access_device'                => '',
		'has_certificate'              => '',
	];

	$course_stats = dozentlms_get_course_content_stats();

	/**
	 * TODO: Add total quiz and total assignments number and downloadable resources
	 */

	array_walk( $items, function ( &$item, $key ) use ( $course_stats ) {
		switch ( $key ) {

			case 'total_lecture' :
				$item_text = sprintf( __( '%d Lectures', 'dozent-lms' ),
					number_format_i18n( $course_stats->total_lectures ) );
				$item
				           = "<p class='dlms-list-item-content'> <i class='lmsicon-book'></i> <span class='dlms-liste-item-text'>{$item_text}</span> </p>";
				break;
			case 'video_length' :
				$item_text = sprintf( __( '%s on-demand video', 'dozent-lms' ), $course_stats->human_readable_duration );
				$item
				           = "<p class='dlms-list-item-content'> <i class='lmsicon-video'></i> <span class='dlms-liste-item-text'>{$item_text}</span> </p>";
				break;
			case 'has_lifetime_access' :
				$item_text = __( 'Lifetime access', 'dozent-lms' );
				$item
				           = "<p class='dlms-list-item-content'> <i class='lmsicon-infinite'></i> <span class='dlms-liste-item-text'>{$item_text}</span> </p>";
				break;

			case 'access_device' :
				$item_text = __( 'Access on smartphone, tablet and tv', 'dozent-lms' );
				$item
				           = "<p class='dlms-list-item-content'> <i class='lmsicon-smartphone'></i> <span class='dlms-liste-item-text'>{$item_text}</span> </p>";
				break;
			case 'has_certificate' :
				$item_text = __( 'Certificate of completion', 'dozent-lms' );
				$item
				           = "<p class='dlms-list-item-content'> <i class='lmsicon-trophy'></i> <span class='dlms-liste-item-text'>{$item_text}</span> </p>";
				break;
		}

	} );


	$items = apply_filters( 'dozentlms_course_whats_included_items', $items, $course );

	return array_filter( $items );
}