<?php

/**
 * Find item_id {lecture_id}
 */

if ( ! empty( $lecture_id ) ) {
    $item_id = $lecture_id;
}

if ( empty( $item_id ) ) {
	$item_id = (int) dozentlms_request_text( 'item_id' );
}

$lecture = get_post( $item_id );
if ( empty( $lecture ) ) {
	return;
}

$video = get_post_meta( $item_id, '_video', true );
$source = dozentlms_arr_get( $video, 'source' );
?>

<div class="lecture-form-html  dlms-p-4 dlms-border">
    <div class="new-lecture-form-header dlms-d-flex dlms-mb-3 dlms-pb-3 dlms-border-bottom">
        <h3 class="flex-grow-1 dlms-m-0">
            <a href="<?php echo admin_url( "post.php?post={$item_id}&action=edit" ) ?>" target="_blank"> <?php _e( 'Edit lecture in default window', 'dozent-lms' ); ?> </a>
        </h3>
        <a href="javascript:;" class="dlms-btn dlms-btn-outline-dark dlms-btn-sm btn-cancel-form" > &times; </a>
    </div>

    <div class="lecture-request-response"></div>

	<?php do_action('dozentlms/edit_lecture_form/before'); ?>
    <input type="hidden" name="lecture_id" value="<?php echo $item_id; ?>">

    <div class="dlms-form-group">
        <input type="text" name="title" class="dlms-form-control"  value="<?php echo $lecture->post_title; ?>" placeholder="<?php _e( 'Lecture Title', 'dozent-lms' ); ?>" >
    </div>

    <div class="dlms-form-group">
        <div class="wpEditorWrap">
            <?php wp_editor( $lecture->post_content, 'lecture_content', [ 'textarea_rows' => 5 ] ); ?>
        </div>
    </div>

    <div class="dlms-form-video-sources">

        <h3> <?php _e( 'Add a video', 'dozent-lms' ); ?> </h3>

        <div class="video-source-segment-wrap <?php echo empty( $source ) ? 'checked' : ''; ?> ">
            <label class="video-source-label" data-video-source="">
                <input type='radio' name='_video[source]' value='' <?php checked( $source, '' ); ?> > <?php _e( 'None', 'dozent-lms' ); ?> </label>
        </div>

		<?php

		$videos  = dozentlms_get_enabled_video_sources();
		foreach ( $videos as $video_key => $video_label ) {
			$video_value = dozentlms_arr_get( $video, $video_key );
			$checked_class = ( $source === $video_key ) ? 'checked' : '';

			echo "<div class='video-source-segment-wrap {$checked_class}'>";
			echo "<label class='video-source-label' data-video-source='{$video_key}'> <input type='radio' name='_video[source]' value='{$video_key}' " . checked( $source, $video_key, false ) . " > {$video_label} </label>";
			?>

            <div class="video-source-input-wrap video-source-<?php echo esc_attr( $video_key ); ?>" style="display: <?php echo ($source === $video_key) ? 'block' : 'none'; ?>;" >
				<?php if ( $video_key === 'upload' ) {
					?>
                    <div class="video-upload-form">

                        <div class="video-choose-wrap">
                            <div class="video-field-label">
                                <label> <?php _e( 'Lecture Video', 'dozent-lms' ); ?> </label>
                                <p class="description"> <?php _e( 'The supported video are .mp4, .ogv or .webm', 'dozent-lms' ); ?> </p>
                            </div>

							<?php dozentlms_upload_field( "_video[{$video_key}][video_id]", dozentlms_arr_get( $video_value, 'video_id' ), 'media' ); ?>
                        </div>

                        <div class="video-poster-wrap">
                            <div class="video-field-label">
                                <label> <?php _e( 'Video Poster', 'dozent-lms' ); ?> </label>
                                <p class="description"> <?php _e( 'Video poster supported files are .jpeg, .png', 'dozent-lms' ); ?> </p>
                            </div>

							<?php dozentlms_upload_field( "_video[{$video_key}][poster_id]", dozentlms_arr_get( $video_value, 'poster_id' ) ); ?>
                        </div>

                    </div>

					<?php
				} elseif ( $video_key === 'youtube' ) {
					?>

                    <input type="text" class="dlms-form-control" name="_video[<?php echo $video_key; ?>]" placeholder="<?php _e( 'YouTube video url', 'dozent-lms' ); ?>" value="<?php echo esc_attr( $video_value ); ?>" />
					<?php

				} elseif ( $video_key === 'vimeo' ) {
					?>
                    <input type="text" class="dlms-form-control" name="_video[<?php echo $video_key; ?>]" placeholder="<?php _e( 'Vimeo video url', 'dozent-lms' ); ?>" value="<?php echo esc_attr( $video_value ); ?>" />
					<?php
				} elseif ( $video_key === 'embedded' ) {
					?>
                    <textarea class="dlms-form-control" name="_video[<?php echo $video_key; ?>]" ><?php esc_textarea( $video_value ); ?></textarea>
                    <p class="description"> <?php _e( 'Place embedded code', 'dozent-lms' ); ?> </p>
					<?php
				}
				?>

				<?php do_action( "dozentlms_form_video_after_{$video_key}" ); ?>
            </div>

			<?php
			echo "</div>";
		}
		?>

        <div class="video-runtime-input-wrap" style="display: <?php echo in_array( $source, array_keys( $videos ) ) ? 'block' : 'none'; ?>;" >

            <label class="description"> <?php _e( 'Video Runtime', 'dozent-lms' ); ?> </label>

            <div class="video-runtime-input-group">
                <input type="text" placeholder="hh" name="_video[runtime][hh]" value="<?php echo dozentlms_arr_get( $video, 'runtime.hh' ); ?>">
                <span> : </span>
                <input type="text" placeholder="mm" name="_video[runtime][mm]" value="<?php echo dozentlms_arr_get( $video, 'runtime.mm' ); ?>">
                <span> : </span>
                <input type="text" placeholder="ss" name="_video[runtime][ss]" value="<?php echo dozentlms_arr_get( $video, 'runtime.ss' ); ?>">
            </div>

            <p class="description"> <?php echo sprintf( __( 'Runtime format - %s', 'dozent-lms' ), '<strong>hh:mm:ss</strong>' ); ?> </p>
        </div>

    </div>

	<?php do_action('dozentlms/edit_lecture_form/after'); ?>

    <div class="dlms-form-group ">
        <button type="submit" class="dlms-btn dlms-btn-info btn-save-lecture"  name="save" value="update_lecture"> <i class="la la-save"></i>  <?php _e('Update Lecture', 'dozent-lms'); ?> </button>
        <button type="button" class="dlms-btn dlms-btn-outline-info btn-cancel-form"> <?php _e('Cancel', 'dozent-lms'); ?> </button>
    </div>

</div>