<?php

function dozentlms_is_course_archive() {
	return is_post_type_archive( 'dozentlms_course' );
}

/**
 * Determine if current single page is a course
 * Or a given post id or post object is actually a course.
 *
 * @since DozentLMS 1.0.0
 * @since DozentLMS 1.2.1 Added $course parameter to check a post is actually course.
 *
 * @param  null  $course
 *
 * @return bool
 */

function dozentlms_is_course( $course = null ) {
	if ( ! empty( $course ) ) {
		$course = get_post( $course );

		if ( ! empty( $course ) && ! empty( $course->post_type ) && ( 'dozentlms_course' === $course->post_type ) ) {
			return true;
		}
	}

	return is_singular( 'dozentlms_course' );
}

function dozentlms_is_lecture(){
	return is_singular( 'dlms_lecture' );
}

function dozentlms_is_syllabus_singular(){

	return dozentlms_is_lecture();
}

function dozentlms_is_frontend_dashboard() {
	$dashboard_page = dozentlms_get_setting( 'dashboard_page_id' );

	if ( $dashboard_page > 0 && is_page( $dashboard_page ) ) {
		return true;
	}

	return false;
}

/**
 * Retrieve the page IDs used by Dozent LMS for displaying various type of contents
 *
 * @since DozentLMS 1.0.0
 *
 * @param string $page dashboard|
 *
 * @return int
 */

function dozentlms_get_page_id( $page ) {
	$page_id = 0;

	if ( $page === 'dashboard' ) {
		$page_id = dozentlms_get_setting( 'dashboard_page_id' );
	} elseif ( $page === 'login' ) {
		$page_id = dozentlms_get_setting( 'login_page_id' );
	}

	return $page_id ? absint( $page_id ) : 0;
}

function dozentlms_is_login() {
	$login_page_id = dozentlms_get_page_id( 'login' );

	return is_page( $login_page_id );
}