<?php

/**
 * Get the form input value from specific input
 * This function works like php $_REQUEST variable
 *
 * @since DozentLMS 1.0.0
 *
 * @param string $field Name of input field
 * @param  null  $default Default value
 *
 * @return string
 */

function dozentlms_request_text( $field, $default = null ) {
	$get_value = dozentlms_get_var( $field, $default );
	if ( ! empty( $get_value ) ) {
		return $get_value;
	}

	return sanitize_text_field( dozentlms_arr_get( $_POST, $field, $default ) );
}

/**
 * Return the get variable value
 * This function works like php $_GET variable
 *
 * @since DozentLMS 1.0.0
 *
 * @param string $field Name of input field
 * @param  null  $default Default value
 *
 * @return string
 */

function dozentlms_get_var( $field, $default = null ) {
	return sanitize_text_field( dozentlms_arr_get( $_GET, $field, $default ) );
}

function dozentlms_request_textarea( $field, $default = null ) {
	return sanitize_textarea_field( dozentlms_arr_get( $_POST, $field, $default ) );
}

/**
 * Generate Media Upload Field
 *
 * @since DozentLMS 1.0.0
 *
 * @param  string  $field_name
 * @param  null  $media_id
 * @param  string  $field_type 'media|image'
 * @param  bool  $echo
 *
 * @return mixed|void
 */

function dozentlms_upload_field( $field_name = 'media_id', $media_id = null, $field_type = 'image', $echo = true ){
	if ( empty( $field_name ) ){
		$field_name = 'media_id';
	}

	ob_start();

	$media_info = wp_prepare_attachment_for_js( $media_id );
	?>

    <div class="dlms-upload-field-wrap field-type-<?php echo $field_type; ?>">
        <input type="hidden" class="media-field" name="<?php echo $field_name; ?>" value="<?php echo $media_id; ?>">

        <a href="javascript:;" class="upload-toggle-btn">
			<?php
			if ( $field_type === 'image' ) {
				$img_src = DOZENTLMS_URL . 'resources/images/image-upload.svg';
				if ( $media_id ) {
					$img_src = dozentlms_arr_get( $media_info, 'sizes.medium.url' );
				}

				echo "<img src='{$img_src}' alt='' class='upload-field-thumbnail' />";
			} else {
				echo '<i class="lmsicon-cloud-upload"></i> ';
				_e( 'Upload Media', 'dozent-lms' );
			}
			?>
        </a>

		<?php
		if ( $field_type !== 'image' && $media_id ) {

		    if ( ! empty( dozentlms_arr_get( $media_info, 'filename' ) ) ) {
			?>
            <div class="uploaded-media-info">
                <p class="media-file-name"> <strong> <?php _e( 'Media', 'dozent-lms' ); ?> : </strong> <span> <?php echo dozentlms_arr_get( $media_info, 'filename' ); ?> </span> </p>
                <p class="media-file-size"> <strong> <?php _e( 'Size', 'dozent-lms' ); ?> : </strong> <span> <?php echo dozentlms_arr_get( $media_info, 'filesizeHumanReadable' ); ?> </span> </p>
            </div>
			<?php
            }
		}
		?>

        <div class="field-actions-wrap" style="display: none;">
            <a href="javascript:;" class="field-upload-btn"><i class="lmsicon-file"></i> <?php _e( 'Choose', 'dozent-lms' ); ?> </a>
            <a href="javascript:;" class="field-clear-btn"><i class="lmsicon-trash"></i> <?php _e( 'Delete', 'dozent-lms' ); ?> </a>
            <a href="javascript:;" class="field-close-btn"> <i class="lmsicon-close"></i> <?php _e( 'Close', 'dozent-lms' ); ?> </a>
        </div>
    </div>
	<?php

	$html = apply_filters( 'dozentlms_upload_field', ob_get_clean(), $field_name, $media_id, $field_type );

	if ( $echo ){
		echo $html;
	}

	return $html;
}

/**
 * Generate HTML for the switch field.
 *
 * @param  string  $name Field Name
 * @param  string  $current Current Value. pass disabled to disable the switch field
 * @param  null  $id ID of the switch field
 * @param  null  $label Label
 *
 * @since 1.1.0
 *
 * @return string
 */

function dozentlms_switch_field( $name = '', $current = 'disabled', $id = null, $label = null ) {
	if ( $id === true ) {
		$id = $name;
	}

	if ( $id ) {
		$id = " id='{$id}' ";
	}

	$attr = checked( (bool) $current, true, false );
	$wrap_class = '';
	if ( $current === 'disabled' ) {
		$attr = " disabled='disabled' ";
		$wrap_class = 'dlms-switch-disabled';
	}

	return "<label class='dlms-switch {$wrap_class}'>
            <input type='checkbox' {$id} name='{$name}' value='1' {$attr} > <span class='switch-title'> {$label} </span> 
        </label>";
}

/**
 * print out of the dozentlms_switch_field()
 *
 * @param  string  $name Field Name
 * @param  string  $current Current Value. pass disabled to disable the switch field
 * @param  null  $id ID of the switch field
 * @param  null  $label Label
 *
 * @since 1.1.0
 *
 * @return string
 */

function dozentlms_switch_field_e( $name = '', $current = '', $id = null, $label = null ) {
    echo dozentlms_switch_field( $name, $current, $id, $label );
}