<?php
function dozentlms_is_archive_sorted(){
	$requested_vars = apply_filters( 'dozentlms_archive_request_vars', dozentlms_arr_sanitize( $_REQUEST ) );

	$default_vars = apply_filters( 'dozentlms_archive_default_vars', [
		'rating',
		'sort_by',
		'video_duration',
		'level',
	] );

	return (bool) array_diff_key( $requested_vars, $default_vars );
}

function dozentlms_get_archive_link(){
	return get_post_type_archive_link( 'dozentlms_course' );
}

function dozentlms_course_per_page() {
	$perpage = (int) dozentlms_get_var( 'per_page' );

	if ( ! $perpage ) {
		$perpage = (int) dozentlms_get_setting( 'show_course_per_page' );
	}

	if ( ! $perpage ) {
		$perpage = (int) get_query_var( 'posts_perpage');
	}

	return apply_filters( 'dozentlms_course_per_page', $perpage );
}

function dozentlms_course_promo( $course = null ){
	$course = get_post( $course );

	$video = get_post_meta( $course->ID, '_video', true );
	$source = dozentlms_arr_get( $video, 'source' );

	if ( ! empty( $source ) ) {
		dozentlms_load_template( 'includes/video' );
    } else {
		dozentlms_featured_image( $course );
    }
}

function dozentlms_featured_image( $course = null, $echo = true ) {
	$course = get_post( $course );

	$img_src = dozentlms_placeholder_src();

	if ( has_post_thumbnail( $course ) ) {
		$img_src = get_the_post_thumbnail_url( $course );
	}

	$permalink = get_the_permalink( $course );
	$title     = get_the_title( $course );

	$img = "<a href='{$permalink}' title='{$title}' class='dlms-cover'> <img src='{$img_src}' class='' alt='{$title}' />  </a>";

	$imgHtml = apply_filters( 'dozentlms_featured_image', $img, $course );

	if ( $echo ) {
		echo $imgHtml;
	}

	return $imgHtml;
}


function dozentlms_pagination( $total_count = 0, $current_page = 0, $per_page = 0, $singular_text = null, $plural_text = null, $echo = true ) {

	global $wp_query;

	if ( ! $per_page ) {
		$per_page = dozentlms_get_var( 'per_page' );
	}

	if ( empty( $per_page ) ) {
		if ( dozentlms_is_course_archive() ) {
			$per_page = dozentlms_course_per_page();

			$singular_text = __( 'Course', 'dozent-lms' );
			$plural_text   = __( 'Courses', 'dozent-lms' );

		} else {
			$per_page = dozentlms_get_setting( 'pagination_results_per_page', 20 );
		}
	}

	if ( empty( $current_page ) ) {
		$current_page = dozentlms_get_current_page_number();
	}

	$current_page = $current_page ? $current_page : dozentlms_get_current_page_number();


	$from_num = ( $current_page - 1 ) * $per_page + 1;
	$to_num   = $from_num + $per_page - 1;

	//Get Total number from $wp_query;
	if ( ! $total_count ) {
		if ( ! empty( $wp_query->found_posts ) ) {
			$total_count = $wp_query->found_posts;
		}
	}

	if ( $to_num >= $total_count ) {
		$to_num = $total_count;
	}

	$pagination_args = apply_filters( 'dozentlms_pagination_args', [
			'total'         => $total_count,
			'current_page'  => $current_page,
			'per_page'      => $per_page,
			'singular_text' => $singular_text,
			'plural_text'   => $plural_text,
			'from_num'      => $from_num,
			'to_num'        => $to_num,
		]
	);

	ob_start();
	dozentlms_load_template( 'includes/pagination', $pagination_args );
	$output = ob_get_clean();

	if ( $echo ) {
		echo $output;
	}

	return $output;
}

function dozentlms_single_course_header(){
	dozentlms_load_template( 'course/single/header' );
}

function dozentlms_enroll_box() {
	dozentlms_load_template( 'course/single/enroll-box' );
}

function dozentlms_course_learning_goal() {
	$learning_goal = get_post_meta( get_the_ID(), '_learning_goal', true );
	$goals_as_array = array_filter( explode( "\n", $learning_goal ) );

	if ( empty( $learning_goal ) || empty( $goals_as_array ) ) {
		return;
	}

	dozentlms_load_template( 'course/single/learning-goal', compact( 'goals_as_array' ) );
}

function dozentlms_course_syllabus() {
	dozentlms_load_template( 'course/single/course-syllabus' );
}

function dozentlms_course_learning_requirements() {
	$learning_requirements = get_post_meta( get_the_ID(), '_learning_requirements', true );
	$requirements_as_array = array_filter( explode( "\n", $learning_requirements ) );

	if ( empty( $learning_requirements ) || empty( $requirements_as_array ) ) {
		return;
	}

	dozentlms_load_template( 'course/single/learning-requirements', compact( 'requirements_as_array' ) );
}

function dozentlms_course_target_student() {
	$target_text = get_post_meta( get_the_ID(), '_targeted_students', true );
	$target_as_array   = array_filter( explode( "\n", $target_text ) );

	if ( empty( $target_text ) || empty( $target_as_array ) ) {
		return;
	}

	dozentlms_load_template( 'course/single/target-student', compact( 'target_as_array' ) );
}

function dozentlms_syllabus_item_content() {
	$course_id = dozentlms_course_id_by_item();

	if ( dozentlms_has_course_access( $course_id ) ) {
		if ( "dlms_lecture" === get_post_type() ) {
			dozentlms_lecture_content();
		} else {
			echo sprintf( __( 'No template function found for the %s post type', 'dozent-lms' ), get_post_type() );
		}
	} else {
		dozentlms_no_access_content();
	}
}

function dozentlms_syllabus_item_sidebar() {
	dozentlms_load_template( 'single/lecture-sidebar' );
}

function dozentlms_lecture_content(){
	dozentlms_load_template( 'single/lecture/content' );
}

function dozentlms_the_video(){
	dozentlms_load_template( 'includes/video' );
}

function dozentlms_course_description(){
	dozentlms_load_template( 'course/single/description' );
}


/**
 * The DozentLMS header.
 *
 * This is the template that displays all of the <head> section and everything up until main.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 */

function dozentlms_header(){
	?>
	<!doctype html>
	<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>" />
		<meta name="viewport" content="width=device-width, initial-scale=1" />
		<?php wp_head(); ?>
	</head>

	<body <?php body_class(); ?>>
	<?php wp_body_open();
}

/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 */

function dozentlms_footer(){
	wp_footer(); ?>

	</body>
	</html>
	<?php
}

function dozentlms_dashboard_link( $endpoint = '' ) {
	$structure     = get_option( 'permalink_structure' );
	$is_pretty_url = empty( $structure ) ? false : true;

	$dashboard_link = get_the_permalink( dozentlms_get_page_id( 'dashboard' ) );

	if ( $dashboard_link ) {
		$dashboard_link = trailingslashit( $dashboard_link );
	}

	if ( $is_pretty_url ) {
		$dashboard_link = trailingslashit( $dashboard_link . $endpoint );
	} else {

		if ( false === strpos( $endpoint, '/' ) ) {
			$dashboard_link = add_query_arg( [ 'dbsegment' => $endpoint ], $dashboard_link );
		} else {

			$segments = explode( '/', $endpoint );

			foreach ( $segments as $key => $segment ) {
				$newKey                         = $key ? $key + 1 : '';
				$segments["dbsegment{$newKey}"] = $segment;
				unset( $segments[ $key ] );
			}

			$dashboard_link = add_query_arg( $segments, $dashboard_link );
		}
	}

	return $dashboard_link;
}

function dozentlms_load_dashboard_template() {
	$dbsegment  = get_query_var( 'dbsegment' );
	$dbsegment2 = get_query_var( 'dbsegment2' );

	$template_name = 'dashboard/dashboard';

	if ( ! empty( $dbsegment ) ) {
		global $dashboard_raw_menu_items;

	    $capability = dozentlms_arr_get( $dashboard_raw_menu_items, "{$dbsegment}.capability" );
	    if ( $capability && ! current_user_can( $capability ) ) {
		    $template_name = 'includes/access-denied';
        } else {
		    $template_name = 'dashboard/' . $dbsegment;

		    if ( ! empty( $dbsegment2 ) ) {
			    $template_name = "dashboard/{$dbsegment}/$dbsegment2";
		    }
        }

	}

	dozentlms_load_template( $template_name, compact( 'dbsegment', 'dbsegment2' ) );
}

function dozentlms_auth_form(){
    dozentlms_load_template( 'includes/auth-form' );
}

function dozentlms_no_access_content(){
	dozentlms_load_template( 'course/no-access' );
}

function dozentlms_dashboard_breadcrumb(){
    dozentlms_load_template( 'dashboard/breadcrumb' );
}

function dozentlms_lecture_complete_form(){
    if ( ! is_user_logged_in() ) {
        return;
    }

	$is_completed = dozentlms_is_lecture_completed( get_the_ID(), get_current_user_id() );

    if ( $is_completed ) {
        return;
    }
    ?>
    <div class="dlms-complete-form">
        <form action="" method="post">
            <input type="hidden" name="complete_lecture_id" value="<?php the_ID(); ?>">
            <button type="submit" class="dlms-btn dlms-btn-primary"> <?php _e( 'Complete Lecture', 'dozent-lms' ); ?> </button>
        </form>
    </div>
<?php
}

function dozentlms_course_completed_label( $course = null, $user_id = 0 ) {
	if ( dozentlms_is_course_completed( $course, $user_id ) ) {
		echo "<span class='dlms-pill'> <i class='lmsicon-check'></i> " . __( 'Course Finished', 'dozent-lms' ) . " </span>";
	}
}

/**
 * Display course progress bar
 *
 * @since DozentLMS 1.1.2
 *
 * @param  null  $course
 *
 * @return string
 */

function dozentlms_course_progress_bar( $course = null ){
    if ( ! is_user_logged_in() ) {
        return '';
    }

	$course = get_post( $course );

	dozentlms_load_template( 'course/single/progress-bar', compact( 'course' ) );
}

/**
 * Render course completion form
 *
 * @since DozentLMS 1.1.3
 */

function dozentlms_course_completion_form(){
    if ( ! is_user_logged_in() ) {
        return;
    }

	dozentlms_load_template( 'course/single/completion-form' );
}

function dozentlms_syllabus_nav_link(){
	dozentlms_load_template( 'course/single/syllabus-nav-link' );
}

function dozentlms_notice( $notice = '', $type = 'info', $echo = true ) {
	$noticeHTML = dozentlms_load_template( 'includes/notice', compact( 'notice', 'type' ), false );

	if ( $echo ) {
	    echo $noticeHTML;
    }
	return $noticeHTML;
}

/**
 * Set a container to max height.
 * If the content height exceeds the max height, then it will show a button called show more
 *
 * @param  null  $content
 * @param  array  $container_class
 * @param int $container_height Wrapper Max Height
 * @param  bool  $echo
 *
 * @return string
 */

function dozentlms_expandable_container( $content = null, $container_class = [], $container_height = null, $echo = true ) {

	$wrap_class = '';
	if ( ! empty( $container_class ) ) {

		if ( is_array( $container_class ) ) {
			$wrap_class = implode( " ", array_filter( $container_class ) );
		} elseif ( is_string( $container_class ) ) {

			$container_class = explode( ',', $container_class );
			if ( ! empty( $container_class ) && is_array( $container_class ) ) {
				$wrap_class = implode( " ", array_filter( $container_class ) );
			}

		}
	}

	$max_height_style = "";
	if ( ! empty( $container_height ) || is_numeric( $container_height ) ) {
		$container_height = $container_height + 30;
	    $max_height_style = "style='max-height: {$container_height}px;'";
	}

	$output
		= "<div class='expandable-container {$wrap_class} ' {$max_height_style}><div class='expandable-container-inner' data-max-height='{$container_height}'> {$content} </div></div>";

	if ( $echo ) {
		echo $output;
	}

	return $output;
}


function dozentlms_course_reviews(){
	if ( ! dozentlms_addon_activated( 'ratings-reviews' ) ) {
		return;
	}

	dozentlms_load_template( 'addons/ratings-reviews/course-reviews' );
}

/**
 * Loop the single review
 *
 * @param object $review Review Data as object
 * @param  string  $screen Page Name or identifier
 * @param  bool  $echo
 *
 * @return string
 */

function dozentlms_loop_review( $review, $screen = 'course_page', $echo = true ) {
	if ( empty( $screen ) ) {
		$screen = 'course_page';
	}

	$reviewHtml = dozentlms_load_template( 'addons/ratings-reviews/loop-review', compact( 'review', 'screen' ),
		false );

	if ( $echo ) {
		echo $reviewHtml;
	}

	return $reviewHtml;
}

/**
 * Course page header rating template function
 *
 * @param  bool  $echo
 *
 * @return string|void
 */

function dozentlms_course_page_header_rating( $echo = true ) {
	if ( ! dozentlms_addon_activated( 'ratings-reviews' ) ) {
		return;
	}

	$html = dozentlms_load_template( 'addons/ratings-reviews/course-page-header-rating', false, false );

	if ( $echo ) {
		echo $html;
	}

	return $html;
}

/**
 * Show a pill elements with text
 *
 * @since DozentLMS 1.2.0
 *
 * @param string $text Pill Content
 * @param  null  $classes Pill element class
 * @param  bool  $echo Whether it should echo or return
 *
 * @return string
 */

function dozentlms_pill( $text , $classes = null, $echo = true ) {
	$class = '';

	if ( ! empty( $classes ) ) {
		if ( is_array( $classes ) && count( $classes ) ) {

			$classes = array_map( function ( $value ) {
				return 'pill-' . $value;
			}, $classes );

			$class = implode( ' ', $classes );
		} else {
			$class = 'pill-' . $classes;
		}
	}

	$class = strtolower( $class );

	$pill_html = "<span class='dlms-pill {$class} '> {$text} </span>";

	if ( $echo ) {
		echo $pill_html;
	}

	return $pill_html;
}

/**
 * Template function to show the Whats Includes element at course page
 *
 * @since DozentLMS 1.2.1
 *
 * @param  null  $course
 * @param bool $echo
 *
 * @return string|void
 */

function dozentlms_course_whats_includes( $course = null, $echo = true ) {
	if ( ! dozentlms_is_course( $course ) ) {
		return;
	}

	$html = dozentlms_load_template( 'course/single/whats-includes', false, false );

	if ( $echo ) {
		echo $html;
	}

	return $html;
}