<?php
/**
 * Hooks File
 */

add_filter( 'template_include', 'dozentlms_course_archive_tmpl' );
add_filter( 'template_include', 'dozentlms_course_single_tmpl' );
add_action( 'pre_get_posts', 'dozentlms_course_archive_query' , 99 );
add_filter( 'template_include', 'dozentlms_lecture_single_tmpl' );

/**
 * Dashboard
 */

add_filter( 'template_include', 'dozentlms_dashboard_tmpl' );

/**
 * Login page Template
 */

add_filter( 'template_include', 'dozentlms_login_tmpl' );

/**
 * Load Course archive page
 *
 * @param $tmpl
 *
 * @return string
 */

function dozentlms_course_archive_tmpl( $tmpl ) {
	if ( dozentlms_is_course_archive() ) {
		$tmpl = dozentlms_locate_template( 'archive-dozentlms_course' );
	}

	return $tmpl;
}

function dozentlms_course_single_tmpl( $tmpl ) {
	if ( dozentlms_is_course() ) {
		$tmpl = dozentlms_locate_template( 'course/single-course' );
	}

	return $tmpl;
}

/**
 * Filter Course Archive Page
 *
 * @param $query
 */

function dozentlms_course_archive_query( $query ) {
	if ( ! dozentlms_is_course_archive() ) {
		return;
	}

	$course_per_page        = dozentlms_course_per_page();
	$filter_course_per_page = intval( dozentlms_get_var( 'per_page' ) );
	if ( $filter_course_per_page ) {
		$course_per_page = $filter_course_per_page;
	}
	$query->set( 'posts_per_page', $course_per_page );

	$sort_by = dozentlms_get_var( 'sort_by' );

	switch ( $sort_by ) {
		case 'title-asc' :
			$query->set( 'orderby', 'post_title' );
			$query->set( 'order', 'ASC' );
			break;
		case 'title-desc' :
			$query->set( 'orderby', 'post_title' );
			$query->set( 'order', 'DESC' );
			break;
		case 'newest' :
			$query->set( 'orderby', 'post_date' );
			$query->set( 'order', 'DESC' );
			break;
		case 'oldest':
			$query->set( 'orderby', 'post_date' );
			$query->set( 'order', 'ASC' );
			break;
	}

}

function dozentlms_lecture_single_tmpl( $tmpl ) {
	if ( dozentlms_is_lecture() ) {
		$tmpl = dozentlms_locate_template( 'course/single-lecture' );
	}

	return $tmpl;
}

function dozentlms_dashboard_tmpl( $tmpl ) {
	if ( ! dozentlms_is_frontend_dashboard() ) {
		return $tmpl;
	}

	global $dashboard_raw_menu_items;
	$dashboard_raw_menu_items = \DozentLMS\Core\User\Panel::raw_menu_items();

	$template_slug = "dashboard/auth";

	if ( is_user_logged_in() ) {
		$template_slug = "dashboard/home";
	}

	/**
	 * Filter dashboard template path
	 *
	 * @since DozentLMS 1.2.0
	 *
	 * @param string $template_path Path of current dashboard page
	 * @param string $template_slug Currently loaded template path.
	 */

	return apply_filters( 'dozentlms_dashboard_tmpl', dozentlms_locate_template( $template_slug ), $template_slug );
}

function dozentlms_login_tmpl( $tmpl ) {
	if ( dozentlms_is_login() ) {

		$redirect_to = dozentlms_get_var( 'redirect_to' );
		if ( ! empty( $redirect_to ) ) {
			dozentlms_set_redirect_to( $redirect_to );
		}

		if ( is_user_logged_in() ) {
			wp_redirect( dozentlms_dashboard_link() );
			exit();
		} else {
			$tmpl = dozentlms_locate_template( 'dashboard/auth' );
		}
	}

	return $tmpl;
}