<?php

/**
 * Instructors List show at the wp-admin area
 */

namespace DozentLMS\Core\Settings;

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( '\WP_List_Table' ) ) {
	require ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class Instructors_List extends \WP_List_Table {

	function __construct() {
		//Set parent defaults
		parent::__construct( array(
			'singular' => 'instructor',     //singular name of the listed records
			'plural'   => 'instructors',    //plural name of the listed records
			'ajax'     => false        //does this table support ajax?
		) );
	}

	function prepare_items() {
		$per_page     = 20;
		$current_page = $this->get_pagenum();
		$start        = ( $current_page - 1 ) * $per_page;

		$search_query = '';
		if ( isset( $_REQUEST['s'] ) ) {
			$search_query = sanitize_text_field( $_REQUEST['s'] );
		}

		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();

		$this->_column_headers = array( $columns, $hidden, $sortable );
		$items                 = dozentlms_get_instructors( $start, $per_page, [ 'search_query' => $search_query ] );

		$this->items = $items->results;

		$this->set_pagination_args( array(
			'total_items' => $items->count,
			'per_page'    => $per_page,
			'total_pages' => ceil( $items->count / $per_page )
		) );
	}

	function get_columns() {
		//Columns from class-wp-users-list-table.php

		return array(
			'cb'       => '<input type="checkbox" />',
			'username' => __( 'User Name', 'dozent-lms' ),
			'name'     => __( 'Name', 'dozent-lms' ),
			'email'    => __( 'Email', 'dozent-lms' ),
			'role'     => __( 'Role', 'dozent-lms' ),
			'courses'  => __( 'Courses', 'dozent-lms' ),
			'actions'  => __( 'Actions', 'dozent-lms' ),
		);
	}

	function column_cb( $item ) {
		return sprintf( '<input type="checkbox" name="%1$s[]" value="%2$s" />', $this->_args['singular'], $item->ID );
	}

	function column_username( $item ) {
		$avatar      = get_avatar( $item->ID, 32 );
		$user_object = get_userdata( $item->ID );

		echo " $avatar <strong> {$user_object->user_login} </strong> ";
	}

	function column_name( $row ){
		$user_object = get_userdata( $row->ID );

		echo "$user_object->first_name $user_object->last_name";
	}

	function column_email( $row ){
		$user_object = get_userdata( $row->ID );

		echo $user_object->user_email;
	}

	function column_role( $row ) {
		$user_object = get_userdata( $row->ID );
		$wp_roles    = wp_roles();

		$role_list = array();

		foreach ( $user_object->roles as $role ) {
			if ( isset( $wp_roles->role_names[ $role ] ) ) {
				$role_list[ $role ] = translate_user_role( $wp_roles->role_names[ $role ] );
			}
		}

		if ( empty( $role_list ) ) {
			$role_list['none'] = _x( 'None', 'no user roles', 'dozent-lms' );
		}

		echo implode( ', ', $role_list );
	}

	function column_courses( $row ){
		//TODO: MultiInstructor get all courses count
		global $wpdb;

		$count = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'dozentlms_course' AND post_author = %d ", $row->ID ) );

		echo intval( $count );
	}

	function column_actions( $row ){
		$account_status = get_user_meta( $row->ID, '_instructor_role', true );

		$action_btn = '';
		if ( 'pending' === $account_status || 'rejected' === $account_status ) {
			$approve_url = add_query_arg( [ 'user_id' => $row->ID, 'action' => 'do_approve' ] );
			$action_btn = "<a href='$approve_url' class='instructor-approve-button'> " . __( 'Approve', 'dozent-lms' ) . " </a>";

		} elseif ( 'approved' === $account_status ) {
			$reject_url = add_query_arg( [ 'user_id' => $row->ID, 'action' => 'do_reject' ] );

			$action_btn = "<a href='$reject_url' class='instructor-reject-button'> " . __( 'Reject', 'dozent-lms' ) . " </a>";
		}

		echo $action_btn;
	}

}