<?php
/**
 * Settings Class
 */

namespace DozentLMS\Core\Settings;

defined( 'ABSPATH' ) || exit;

class Settings {

    /*
     * contains array value
     * @var array
     */

	public $form_fields;

	private $wp_pages = [];

	public function __construct() {
		$this->form_fields = $this->form_fields();
	}

	public function panel() {
		include DOZENTLMS_ABSPATH . '/core/settings/panel.php';
	}

	public function render_element( $field ){
		$title = dozentlms_arr_get(  $field, 'title' );
		$type = dozentlms_arr_get(  $field, 'type' );
		$field_name = dozentlms_arr_get( $field, 'field_name' );
		$default = dozentlms_arr_get( $field, 'default' );
		$field_options = (array) dozentlms_arr_get( $field, 'options', [] );
		$options = array_filter( $field_options );
		$settings_value = $this->get_settings_value( $field_name );

		if ( $settings_value === false && ( is_numeric( $default ) || ! empty( $default ) ) ) {
			$settings_value = $default;
		}

		switch ( $type ) {
			case 'text':
				?>
                <input name="_dozentlms_settings[<?php echo $field_name; ?>]" type="text" id="<?php echo $field_name; ?>" class="regular-text" value="<?php echo $settings_value; ?>" >
				<?php
				break;
			case 'text_disabled':
				?>
                <input type="text" name="_dozentlms_settings[<?php echo $field_name; ?>]" class="regular-text" value="<?php echo $settings_value; ?>" disabled="disabled" >
				<?php
				break;
			case 'number':
				$min = dozentlms_arr_get( $field, 'min' );
				$max = dozentlms_arr_get( $field, 'max' );

				$min_attr = '';
				$max_attr = '';
				if ( $min != null || $min != false ) {
				    $min_attr = 'min="' . esc_attr( $min ) . '"';
				}
				if ( $max != null || $max != false ) {
					$max_attr = 'max="' . esc_attr( $max ) . '"';
				}
				?>
                <input name="_dozentlms_settings[<?php echo $field_name; ?>]" type="number" id="<?php echo $field_name; ?>" class="regular-text" value="<?php echo $settings_value; ?>" <?php echo $min_attr . ' '. $max_attr; ?> >
				<?php
				break;
			case 'checkbox':

				if ( is_array( $options ) && count( $options ) ) {
					$settings_value = (array) $settings_value;

					foreach ( $options as $option_key => $option_value ) {
						?>
                        <p>
                            <label>
                                <input name="_dozentlms_settings[<?php echo $field_name; ?>][]" type="checkbox" value="<?php echo $option_key; ?>" <?php checked( 1, in_array( $option_key, $settings_value ) ); ?> >
								<?php echo $option_value; ?>
                            </label>
                        </p>
						<?php

					}

				} else {
					?>
                    <label>
                        <input name="_dozentlms_settings[<?php echo $field_name; ?>]" type="checkbox" id="<?php echo $field_name; ?>" value="1" <?php checked( '1', $settings_value ) ?> >
						<?php echo $title; ?>
                    </label>
					<?php
				}
				break;
			case 'radio':

				foreach ( $options as $option_key => $option_value ) {
					?>
                    <p>
                        <label>
                            <input name="_dozentlms_settings[<?php echo $field_name; ?>]" type="radio" value="<?php echo $option_key; ?>" <?php checked( $option_key, $settings_value ) ?> >
							<?php echo $option_value; ?>
                        </label>
                    </p>
					<?php
				}
				break;
			case 'select':

				$no_select_option = dozentlms_arr_get(  $field, 'no_select_option' );

				echo "<select class='dozentlms_select2' name='_dozentlms_settings[{$field_name}]'>";

				if ( ! $no_select_option ) {
					echo "<option value=''> " . __( 'Select Option', 'dozent-lms' ) . " </option>";
				}

				foreach ( $options as $option_value => $option_text ) {
					echo "<option value='{$option_value}' " . selected( $option_value, $settings_value, false ) . " > {$option_text} </option>";
				}
				echo "</select>";

				break;

			case 'image':
				dozentlms_upload_field( "_dozentlms_settings[{$field_name}]", $settings_value );
				break;

            case 'slider':

                if ( empty( $settings_value ) && $default > 0 ) {
	                $settings_value = $default;
                }

                ?>

                <div class="slider-field-wrap">
                    <div class="slider" data-min="<?php echo dozentlms_arr_get( $options, 'min' ); ?>" data-max="<?php echo dozentlms_arr_get( $options, 'max' ); ?>" data-step="<?php echo max( 1 , dozentlms_arr_get( $options, 'step' ) ); ?>" data-start="<?php echo max( 1, $settings_value ); ?>"></div>

                    <p class="slider-value"> <strong> <?php _e( 'Value', 'dozent-lms' ) ?> </strong> <span></span> </p>

                    <input type="hidden" class="slider-field" name="_dozentlms_settings[<?php echo $field_name; ?>]" value="<?php echo $settings_value; ?>" >
                </div>
                <?php
                break;

            case 'switch' :
                echo dozentlms_switch_field( "_dozentlms_settings[{$field_name}]", $settings_value );
                break;
		}
    }

	public function form_fields() {
		foreach ( get_pages() as $page ) {
			$this->wp_pages[ $page->ID ] = $page->post_title . " - ID:{$page->ID} ";
		}

		$settings_fields = [];

		$settings_fields['general'] = apply_filters( 'dozentlms_settings_args_general', [
			'title'       => __( 'General', 'dozent-lms' ),
			'form_fields' => [

				'general' => [
					'title'        => __( 'General', 'dozent-lms' ),
					'description'  => __( 'General Settings', 'dozent-lms' ),
					'input_fields' => [

						'site_brand_logo' => [
							'type'        => 'image',
							'label'       => __( 'Site Brand Logo', 'dozent-lms' ),
							'description' => __( 'Upload a brand logo. It will appear where necessary', 'dozent-lms' ),
						],

					],
				],

			],
		] );

		$settings_fields['instructors'] = apply_filters( 'dozentlms_settings_instructors_args', [
			'title'       => __( 'Instructors', 'dozent-lms' ),
			'form_fields' => [

				'general' => [
					'title'        => __( 'Instructors', 'dozent-lms' ),
					'description'  => __( 'Change instructors settings', 'dozent-lms' ),

					'input_fields' => [

						'instructor_account_creation_enable' => [
							'type'        => 'switch',
							'label'       => __( 'Instructor Account Creation', 'dozent-lms' ),
							'title'       => __( 'Enable', 'dozent-lms' ),
							'description' => __( 'Allow users to create instructor account on the "Dashboard". A button will be available to become an instructor.',
								'dozent-lms' ),
						],

						'instructor_account_auto_approve' => [
							'type'        => 'switch',
							'label'       => __( 'Auto Approve Instructor Account ', 'dozent-lms' ),
							'description' => __( 'Automatically approve instructor account after signup.',
								'dozent-lms' ),
						],

					],
				],

			]
		] );

		$settings_fields['permalinks'] = apply_filters( 'dozentlms_settings_permalinks_args', [
			'title'       => __( 'Permalinks', 'dozent-lms' ),
			'form_fields' => [

				'general' => [
					'title'        => __( 'Permalinks', 'dozent-lms' ),
					'description'  => __( 'Create custom URL structure for the courses, lectures, and pages',
						'dozent-lms' ),
					'input_fields' => [

						'course_base_slug' => [
							'type'        => 'text',
							'label'       => __( 'Course Base Slug', 'dozent-lms' ),
							'description' => sprintf( __( 'Enter the slug you’d like to use for course base, Example: %s',
								'dozent-lms' ), '<i>' . site_url() . '/<strong>courses</strong>/sample-course </i> ' ),
						],

						'lecture_base_slug' => [
							'type'        => 'text',
							'label'       => __( 'Lecture Base Slug', 'dozent-lms' ),
							'description' => sprintf( __( 'Enter the slug you’d like to use for lecture base, Example: %s',
								'dozent-lms' ),
								'<i>' . site_url() . '/<strong>lecture</strong>/sample-lecture-slug </i> ' ),
						],

						'category_base_slug' => [
							'type'        => 'text',
							'label'       => __( 'Category Base Slug', 'dozent-lms' ),
							'description' => __( 'Enter the slug you’d like to use for category base', 'dozent-lms' ),
						],

					],
				],

			]
		] );

		$settings_fields['reading_settings'] = apply_filters( 'dozentlms_settings_static_pages_args', [
			'title'       => __( 'Reading Settings', 'dozent-lms' ),
			'form_fields' => [

				'basic_settings' => [
					'title'        => __( 'Basic Settings', 'dozent-lms' ),
					'description'  => __( 'Set the basic configuration of the Reading', 'dozent-lms' ),
					'input_fields' => [

						'pagination_results_per_page' => [
							'type'        => 'slider',
							'label'       => __( 'Pagination Results Per Page', 'dozent-lms' ),
							'default'     => '20',
							'options'     => [ 'min' => 1, 'max' => 50 ],
							'description' => __( 'Set show per page number you’d like to query and display the results per page',
								'dozent-lms' ),
						],
					],
				],

				'course_settings' => [
					'title'        => __( 'Course Settings', 'dozent-lms' ),
					'description'  => __( 'Course settings', 'dozent-lms' ),
					'input_fields' => [
						'show_course_per_row' => [
							'type'        => 'slider',
							'label'       => __( 'Course Per Row', 'dozent-lms' ),
							'default'     => '4',
							'options'     => [ 'min' => 1, 'max' => 6, 'step' => 1 ],
							'description' => __( 'Set the number of courses you’d like to show per row', 'dozent-lms' ),
						],

						'show_course_per_page' => [
							'type'        => 'slider',
							'label'       => __( 'Course Per Page', 'dozent-lms' ),
							'default'     => '20',
							'options'     => [ 'min' => 1, 'max' => 50 ],
							'description' => __( 'Set the number of courses you’d like to show per page',
								'dozent-lms' ),
						],
					],
				],

				'static_pages' => [
					'title'        => __( 'Static Pages settings', 'dozent-lms' ),
					'description'  => __( 'Setup static pages to display content of the Dozent LMS', 'dozent-lms' ),
					'input_fields' => [

						'dashboard_page_id' => [
							'type'        => 'select',
							'label'       => __( 'Frontend Dashboard Page', 'dozent-lms' ),
							'description' => __( 'Setup Frontend dashboard page where users can manage their account',
								'dozent-lms' ),
							'options'     => $this->wp_pages,
						],


					],
				],

			]
		] );


		$settings_fields['login'] = apply_filters( 'dozentlms_settings_social_login_args', [
			'title'       => __( 'Login', 'dozent-lms' ),
			'form_fields' => [
				'login_settings' => [
					'title'        => __( 'Login Settings', 'dozent-lms' ),
					'description'  => __( 'Manage settings related login', 'dozent-lms' ),
					'input_fields' => [

						'login_page_id' => [
							'type'        => 'select',
							'label'       => __( 'Login Page', 'dozent-lms' ),
							'description' => __( 'Set a login page to show the login form', 'dozent-lms' ),
							'options'     => $this->wp_pages,
						],

					],
				]
			]
		] );


		return apply_filters( 'dozentlms_settings_args', $settings_fields );
	}

	public function get_settings_value( $settings = '', $default = false ){
		return dozentlms_arr_get( get_option( 'dozentlms_settings' ), $settings, $default );
	}

	public static function only_field_items() {
		$form_fields = ( new Settings() )->form_fields();

		$input_fields = wp_list_pluck( $form_fields, 'form_fields' );
		$input_fields = array_values( call_user_func_array( 'array_merge', $input_fields ) );

		$fields       = wp_list_pluck( $input_fields, 'input_fields' );
		$field_keys   = array_keys( call_user_func_array( 'array_merge', $fields ) );
		$field_values = array_values( call_user_func_array( 'array_merge', $fields ) );

		return array_combine( $field_keys, $field_values );
	}

}