<?php

function dozentlms_get_login_url( $provider = '' ) {
	$structure       = get_option( 'permalink_structure' );
	$is_pretty_url   = empty( $structure ) ? false : true;
	$login_page_link = get_the_permalink( dozentlms_get_page_id( 'login' ) );


	if ( empty( $provider ) ) {
		return $login_page_link;
	}

	if ( ! empty( $login_page_link ) ) {

		if ( $is_pretty_url ) {
			$login_url = trailingslashit( $login_page_link ) . $provider;
		} else {
			$login_url = add_query_arg( [ 'social_login_attempt' => $provider ], trailingslashit( $login_page_link ) );
		}

	} else {
		if ( $is_pretty_url ) {
			$login_url = trailingslashit( home_url() ) . "social-login-attempt/{$provider}";
		} else {
			$login_url = add_query_arg( [ 'social_login_attempt' => $provider ], trailingslashit( home_url() ) );
		}
	}

	return apply_filters( 'dozentlms_social_login_url', $login_url, $provider );
}

function dozentlms_social_login_providers() {
	return apply_filters( 'dozentlms_social_login_providers', [
		'facebook' => __( 'Facebook', 'dozent-lms' ),
		'google'   => __( 'Google', 'dozent-lms' ),
	] );
}

function dozentlms_become_instructor( $user_id ) {
	update_user_meta( $user_id, '_instructor_role', 'pending' );

	$auto_approve = dozentlms_get_setting( 'instructor_account_auto_approve' );
	if ( $auto_approve ) {
		dozentlms_approve_instructor( $user_id );
	}
}

function dozentlms_approve_instructor( $user_id ) {
	update_user_meta( $user_id, '_instructor_role', 'approved' );

	$instructor = new WP_User( $user_id );
	$instructor->add_role( 'dozentlms_instructor' );

	do_action( 'dozentlms/instructor/approved', $user_id );
}

function dozentlms_get_instructors( $start = 0, $per_page = 10, $args = [] ) {
	global $wpdb;

	$response = [
		'count'   => 0,
		'results' => null,
	];

	$defaults = apply_filters( 'dozentlms_get_instructors_args', [
		'search_query' => '',
	] );

	$r = wp_parse_args( $args, $defaults );
	extract( $r, EXTR_SKIP );

	$search_sql = '';

	if ( ! empty( $search_query ) ) {
		$search_sql
			= " AND ( {$wpdb->users}.user_nicename LIKE '%{$search_query}%' OR {$wpdb->users}.user_email LIKE '%{$search_query}%' OR {$wpdb->users}.display_name LIKE '%{$search_query}%' ) ";
	}

	$limit_query = '';
	if ( $per_page != '-1' ) { //wp standard per_page value
		$limit_query = " LIMIT {$start}, {$per_page}  ";
	}

	$result_count = $wpdb->get_var(
		"SELECT COUNT({$wpdb->users}.ID) 
			FROM $wpdb->users
			INNER JOIN $wpdb->usermeta
			ON {$wpdb->users}.ID = {$wpdb->usermeta}.user_id 
			WHERE {$wpdb->usermeta}.meta_key = '_instructor_role' {$search_sql} ;"
	);

	if ( ! empty( $result_count ) && $result_count > 0 ) {

		$results = $wpdb->get_results(
			"SELECT {$wpdb->users}.* 
			FROM $wpdb->users 
			INNER JOIN $wpdb->usermeta 
			ON {$wpdb->users}.ID = {$wpdb->usermeta}.user_id 
			WHERE {$wpdb->usermeta}.meta_key = '_instructor_role' {$search_sql}
			ORDER BY ID DESC {$limit_query} "
		);

		$response = [
			'count'   => intval( $result_count ),
			'results' => $results,
		];

	}

	return (object) $response;
}

/**
 * Generate and return user avatar. If there is any profile photo uploaded from the dashboard, then the photo will be return, or the first and second latter will be returned from the name.
 *
 * @since DozentLMS 1.1.9
 *
 * @param string|int $id_or_email Users ID or E-Mail
 *
 * @return string|null
 */

function dozentlms_get_avatar( $id_or_email ) {
	$user = null;
	if ( is_numeric( $id_or_email ) ) {
		$user = get_user_by( 'id', $id_or_email );
	} elseif ( is_email( $id_or_email ) ) {
		$user = get_user_by( 'email', $id_or_email );
	}

	if ( empty( $user->display_name ) ) {
		return null;
	}

	$name            = trim( $user->display_name );
	$name_avatar_txt = substr( $name, 0, 2 );
	$name_parts      = explode( " ", $name );
	if ( is_array( $name_parts ) && count( $name_parts ) > 1 ) {
		$name_avatar_txt = substr( dozentlms_arr_get( $name_parts, 0 ), 0, 1 ) . substr( dozentlms_arr_get( $name_parts,
				1 ), 0, 1 );
	}

	$name_avatar_txt = strtoupper( $name_avatar_txt );

	$wrap = "<div class='dlms-avatar-wrap'> {$name_avatar_txt} </div>";

	return $wrap;
}