<?php

/**
 * Frontend Resources Class
 */

namespace DozentLMS\Resources;

class Resources {

	function __construct() {
		//
	}

	public static function instance() {
		static $instance = null;

		if ( null === $instance ) {
			$instance = new Resources();
			$instance->load_resources();
		}

		return $instance;
	}

	function load_resources() {
		add_action( 'admin_enqueue_scripts', [ $this, 'enqueue_scripts' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ] );
	}

	public function enqueue_scripts( $screen ) {
		if ( is_admin() ) {
			wp_enqueue_media();

			if ( $screen === 'dozentlms_page_dozentlms-settings' ) {
				wp_enqueue_style( 'dozentLMSnoUiSlider',
					DOZENTLMS_URL . "resources/libraries/noUiSlider/nouislider.min.css", [], DOZENTLMS_VERSION );

				wp_enqueue_script( 'dozentLMSnoUiSlider',
					DOZENTLMS_URL . "resources/libraries/noUiSlider/nouislider.min.js",
					[], DOZENTLMS_VERSION, true );
			}

		}

		$suffix  = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
		$rtl_dir = is_rtl() ? '-rtl' : '';

		wp_enqueue_style( 'dozentlms', DOZENTLMS_URL . "resources/css{$rtl_dir}/style{$suffix}.css", [],
			DOZENTLMS_VERSION );
		wp_enqueue_script( 'dozentlms', DOZENTLMS_URL . "resources/js/main{$suffix}.js", [ 'jquery' ],
			DOZENTLMS_VERSION, true );

		wp_localize_script( 'dozentlms', '_dozentlms', $this->localize_strings() );

		if ( ! is_admin() ) {
			$this->load_frontend_resources();
		}

	}

	public function localize_strings() {
		$arr = apply_filters( 'dozentlms_localize_strings', [
			'ajaxurl'                  => admin_url( 'admin-ajax.php' ),
			'placeholder_src'          => dozentlms_placeholder_src(),
			'is_logged_in'             => is_user_logged_in(),
			'current_dashboard_screen' => dozentlms_get_current_dashboard_page_slug(),
			'module_name_required'     => __( 'Module name field is required', 'dozent-lms' ),
			'module_created'           => __( 'New module has been created', 'dozent-lms' ),
			'module_updated'           => __( 'Module has been updated', 'dozent-lms' ),
			'lecture_created'          => __( 'Lecture created', 'dozent-lms' ),
			'lecture_updated'          => __( 'Lecture updated', 'dozent-lms' ),
			'wp_select_media'          => __( 'Select or Upload Media', 'dozent-lms' ),
			'wp_use_media'             => __( 'Use this media', 'dozent-lms' ),
			'media'                    => __( 'Media', 'dozent-lms' ),
			'size'                     => __( 'Size', 'dozent-lms' ),
			'settings_changed'         => __( 'Settings have changed, you should save them', 'dozent-lms' ),
			'fullname_required'        => __( 'The Full Name field is required', 'dozent-lms' ),
			'username_email_required'  => __( 'The Username or email address field is required', 'dozent-lms' ),
			'username_required'        => __( 'The Username field is required', 'dozent-lms' ),
			'email_required'           => __( 'The E-Mail field is required', 'dozent-lms' ),
			'password_required'        => __( 'The Password field is required', 'dozent-lms' ),
			'expand_modules'           => __( 'Expand all modules', 'dozent-lms' ),
			'collapse_modules'         => __( 'Collapse all modules', 'dozent-lms' ),
			'show_more_text'           => __( 'Show More +', 'dozent-lms' ),

			'fcb_auto_save'               => (bool) dozentlms_get_setting( 'fcb_auto_save' ),
			'fcb_auto_save_time_interval' => (int) dozentlms_get_setting( 'fcb_auto_save_time_interval' ),
		] );

		return $arr;
	}

	public function load_frontend_resources() {
		//Load VideoJS

		if ( dozentlms_is_course() || dozentlms_is_lecture() ) {
			$video = dozentlms_get_course_video();
			if ( ! empty( $video ) || 'embedded' != dozentlms_arr_get( $video, 'source' ) ) {

				wp_enqueue_style( 'dozentlms-videojs', DOZENTLMS_URL . 'resources/libraries/videojs/videojs.min.css', [], DOZENTLMS_VERSION );
				wp_enqueue_script( 'dozentlms-videojs', DOZENTLMS_URL . 'resources/libraries/videojs/videojs.min.js', [], DOZENTLMS_VERSION, true );

				$video_source = dozentlms_arr_get( $video, 'source' );

				if ( 'youtube' === $video_source ) {
					wp_enqueue_script( 'dozentlms-videojs-youtube', DOZENTLMS_URL . "resources/libraries/videojs/Youtube.min.js", [ 'dozentlms-videojs' ], DOZENTLMS_VERSION, true );
				} elseif ( 'vimeo' === $video_source ) {
					wp_enqueue_script( 'dozentlms-videojs-vimeo', DOZENTLMS_URL . "resources/libraries/videojs/Vimeo.min.js", [ 'dozentlms-videojs' ], DOZENTLMS_VERSION, true );
				}
			}
		}

	}

}