/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.addons = {

        start: function() {
            this.addListeners();
        },

        addListeners: function() {
            //Remove Product from the Course
            $( document ).on( 'click', '.course-product-remove', this.detachProductFromCourse.bind( this ) );

            //Rating and Reviews addon
            $( document ).on( 'click', '.toggle-save-rating-btn', this.openReviewModal.bind( this ) );
            $( document ).on( 'click', '#dlms-review-cancel-btn', this.closeReviewModal.bind( this ) );

            $( document ).on( 'mouseenter', '.dlms-rating-input-wrap .star-rating-icons i', this.hoverOnRating.bind( this ) );
            //Touch supports for the star rating
            $( document ).on( 'click', '.dlms-rating-input-wrap .star-rating-icons i', this.setRatingValue.bind( this ) );
            $( document ).on( 'submit', '#dlms-review-form', this.saveReview.bind( this ) );

            /**
             * Course Page Reviews
             * Filter Reviews
             */

            $( document ).on( 'submit', '#dlms-reviews-search-input-form', this.searchReviews.bind( this ) );
            $( document ).on( 'change', '#dlms-reviews-filter-rating', this.searchReviews.bind( this ) );
            $( document ).on( 'click', 'button.review-summery-rating-row', this.fitlerReviewsByRating.bind( this ) );
            $( document ).on( 'click', '.reviews-show-ore-btn', this.showMoreReviews.bind( this ) );

        },

        detachProductFromCourse: function( e ){
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var course_id = $btn.data( 'course-id' );
            var product_id = $btn.data( 'product-id' );

            $btn.closest( '.course-product-associated-wrap' ).remove();
            $.post( _dozentlms.ajaxurl, { course_id: course_id, product_id : product_id, 'action': 'dozentlms_detach_product_from_course'} );
        },

        openReviewModal: function( e ){
            dozentlms.rate_review_modal.show();
        },
        closeReviewModal: function( e ) {
            e.preventDefault();

            dozentlms.rate_review_modal.hide();
        },
        
        hoverOnRating: function( e ) {
            e.preventDefault();

            var $ratingI = $( e.currentTarget );
            $ratingI.siblings( 'i' ).removeClass( 'lmsicon-star-full lmsicon-star-half' ).addClass( 'lmsicon-star-empty' );

            var ratingValue = $ratingI.data( 'rating' );

            //Set Rating Value
            $ratingI.closest( '.dlms-rating-input-wrap' ).find( 'input[name="rating_input_value"]' ).val( ratingValue );

            //Fill the star until selected one.
            for ( let rating_i = 1; rating_i <= ratingValue; rating_i++ ) {
                $ratingI.closest( '.star-rating-icons' ).find( 'i[data-rating="' + rating_i + '"]' ).addClass( 'lmsicon-star-full' ).removeClass( 'lmsicon-star-empty' );
            }

        },

        setRatingValue: function( e ) {
            e.preventDefault();

            var $ratingItem = $( e.currentTarget );
            var ratingValue = $ratingItem.data( 'rating' );

            $ratingItem.closest( '.dlms-rating-input-wrap' ).find( 'input[name="rating_input_value"]' ).val( ratingValue );
        },

        saveReview: function( e ) {
            e.preventDefault();

            var $form = $( e.currentTarget );
            var $btn = $form.find( '#dlms-save-review-btn' );
            var data = $form.serialize();

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: data,
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        dozentlms.rate_review_modal.hide();
                        window.location.reload();
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );

        },

        showMoreReviews: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var course_id = $btn.attr( 'data-course-id' );
            var page = $btn.attr( 'data-page' );

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: { course_id : course_id, page : page, action : 'dozentlms_show_more_reviews' },
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {

                        if ( response.data.results_html ) {
                            $( '.course-page-reviews-list-wrap' ).append( response.data.results_html );
                        }

                        if ( response.data.page ) {
                            $btn.attr( 'data-page', response.data.page );
                        }

                        if ( ! response.data.results_left ) {
                            $btn.remove();
                        }

                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );

        },

        searchReviews: function( e ) {
            e.preventDefault();

            this.filterReviews();
        },

        fitlerReviewsByRating: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var rating = $btn.data( 'rating' );
            $( '#dlms-reviews-filter-rating' ).val( rating );

            this.filterReviews();
        },

        filterReviews: function() {
            var course_id = $( '#dlms-reviews-course-id' ).val();
            var search_text = $( '#dlms-reviews-search-input' ).val();
            var rating = $( '#dlms-reviews-filter-rating' ).val();
            var $btn = $( '.reviews-show-ore-btn' );

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: { course_id : course_id, search_text : search_text, rating: rating, action : 'dozentlms_filter_reviews' },
                success: function( response ) {
                    if ( response.success ) {

                        $( '.course-page-reviews-list-wrap' ).html( response.data.results_html );
                        $btn.attr( 'data-page', 1 );

                        if ( ! response.data.results_left ) {
                            $btn.hide();
                        } else {
                            $btn.show();
                        }

                    }
                }
            } );
        }
        
        

    };

    /**
     * Start Addons
     */

    dozentlms.addons.start();

})( jQuery );;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.admin = {

        start: function() {
            this.addListeners();
            this.noUiSlider();
        },

        addListeners: function() {
            $( document ).on( 'change', '#DozentLMSSettingsForm', this.changedSettings.bind( this ) );
            $( document ).on( 'submit', '#DozentLMSSettingsForm', this.saveSettings.bind( this ) );

            /**
             * Course Data Panel...
             */
            $( document ).on( 'click', '.dlms-coursedata-navs li a', this.courseDataPanel.bind( this ) );
            $( document ).on( 'change', '[name="course_access_type"]', this.changeCoursePrice.bind( this ) );

            /**
             * Add-Ons Page
             */

            $( document ).on( 'change', '.doznetlms-addons-list [type="checkbox"]', this.addonToggle.bind( this ) );

        },

        changedSettings: function( e ) {
            $( '#settings-panel-notice-wrap' ).
                html( '<p class="changes-warning"><strong>' + _dozentlms.settings_changed + '</strong></p>' );
        },

        saveSettings: function( e ) {
            e.preventDefault();

            $( '#settings-panel-notice-wrap' ).html( '' );
            var $form = $( e.currentTarget );

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: $form.serialize(),
                beforeSend: function() {
                    $form.find( '.save-button' ).addClass( 'icon-spinner' );
                },
                complete: function() {
                    $form.find( '.save-button' ).removeClass( 'icon-spinner' );
                }
            } );
        },

        courseDataPanel: function( e ){
            e.preventDefault();

            var $target = $( e.currentTarget );
            var target_attr = $target.attr( 'data-target' );

            $( '.dlms-coursedata-navs li a' ).removeClass( 'active' );
            $target.addClass( 'active' );

            $( '.coursedata-panel' ).addClass( 'hidden' );
            $( target_attr ).removeClass( 'hidden' );

            window.history.pushState({}, '', $target.attr( 'href' ));
        },

        changeCoursePrice: function( e ){
            var $target = $( e.currentTarget );
            var value = $target.val();

            $( '.price-type-fields' ).addClass( 'dlms-hide' );
            if ( $( '.price-type-' + value + '-fields' ).length ) {
                $( '.price-type-' + value + '-fields' ).removeClass( 'dlms-hide' );
            }

            $( '.dlms-course-pricing-option' ).removeClass( 'checked' );
            $target.closest( '.dlms-course-pricing-option' ).addClass( 'checked' );
        },

        addonToggle: function( e ){
            e.preventDefault();

            var $target = $( e.currentTarget );
            var addon_name = $target.attr( 'name' );
            var is_activated = $target.prop( 'checked' );

            $.post( _dozentlms.ajaxurl, { addon_name: addon_name, is_activated : is_activated, 'action': 'dozentlms_addon_toggle'} );
        },

        noUiSlider: function() {

            if ( typeof noUiSlider !== 'undefined' ) {
                var $sliders = $( '.slider' );

                $sliders.each( function() {
                    var $slider = $( this );

                    var start = parseInt( $slider.data( 'start' ) );
                    var min = parseInt( $slider.data( 'min' ) );
                    var max = parseInt( $slider.data( 'max' ) );
                    var step = parseInt( $slider.data( 'step' ) );

                    noUiSlider.create( this, {
                        start: start,
                        step: step,
                        connect: [true, false],
                        range: {
                            'min': min,
                            'max': max
                        }
                    } );

                    this.noUiSlider.on( 'update', function( values ) {
                        var value = parseInt( values.join() );

                        $slider.siblings( '.slider-value' ).find( 'span' ).html( value );
                        $slider.siblings( '.slider-field' ).val( value );
                    } );
                } );
            }

        }

    };

    /**
     * Start course builder
     */

    dozentlms.admin.start();

})( jQuery );;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.auth = {

        start: function() {
            this.addListeners();
        },

        addListeners: function() {
            $( document ).on( 'click', '.dlms-auth-form-switch a, .auth-lost-password', this.switchLoginForm.bind( this ) );
            $( document ).on( 'submit', 'form.auth-login-form', this.submitLoginForm.bind( this ) );
            $( document ).on( 'submit', 'form.auth-register-form', this.submitRegisterForm.bind( this ) );
            $( document ).on( 'submit', 'form.auth-lost-password-form', this.submitLostPasswordForm.bind( this ) );
        },

        switchLoginForm: function( e ){
            e.preventDefault();

            var $that = $( e.currentTarget );

            $( '.auth_form_response' ).html( '' );
            $( '.error-text' ).remove();

            $( '.dlms-auth-form-switch a' ).removeClass( 'active' );
            $that.addClass( 'active' );
            $( '.auth-tab-content' ).addClass( 'hide' );
            $( $that.attr( 'data-target' ) ).removeClass( 'hide' );
        },

        submitLoginForm: function( e ){
            e.preventDefault();

            var $form = $( e.currentTarget );
            $form.find( '.error-text' ).remove();
            $( '.auth_form_response' ).html( '' );
            
            var $username = $form.find( '[name="username"]' );
            var $password = $form.find( '[name="password"]' );

            var username = dlms_trim( $username.val() );
            var password = dlms_trim( $password.val() );
            var validated = true;

            if ( ! username.length ) {
                validated = false;

                $username.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.username_email_required + ' </p>' );
            }

            if ( ! password.length ) {
                validated = false;

                $password.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.password_required + ' </p>' );
            }

            if ( validated ) {

                var $btn = $form.find( '[type="submit"]' );
                var form_data = $form.serialize() + '&action=dlms_auth_login';

                $.ajax( {
                    url: _dozentlms.ajaxurl,
                    type: 'POST',
                    data: form_data,
                    beforeSend: function() {
                        $btn.attr( 'disabled', 'disabled' ).addClass( 'icon-spinner' );
                    },
                    success: function( response ) {
                        if ( response.success ) {
                            $form.trigger("reset");

                            if ( response.data && response.data.redirect ) {
                                location.href = response.data.redirect;
                            } else {
                                location.reload();
                            }

                        } else if( response.data ) {
                            $( '.auth_form_response' ).html( '<p class="form-response-error"> ' + response.data.message + ' </p>' );
                        }
                    },
                    complete: function() {
                        $btn.removeAttr( 'disabled' ).removeClass( 'icon-spinner' );
                    }
                } );
            }

        },

        submitRegisterForm: function( e ){
            e.preventDefault();

            var $form = $( e.currentTarget );
            var $fullname = $form.find( '[name="fullname"]' );
            var $username = $form.find( '[name="username"]' );
            var $email = $form.find( '[name="email"]' );
            var $password = $form.find( '[name="password"]' );

            $form.find( '.error-text' ).remove();
            $( '.auth_form_response' ).html( '' );

            var fullname = dlms_trim( $fullname.val() );
            var username = dlms_trim( $username.val() );
            var email = dlms_trim( $email.val() );
            var password = dlms_trim( $password.val() );
            var validated = true;

            if ( ! fullname.length ) {
                validated = false;

                $fullname.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.fullname_required + ' </p>' );
            }

            if ( ! username.length ) {
                validated = false;

                $username.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.username_required + ' </p>' );
            }

            if ( ! email.length ) {
                validated = false;

                $email.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.email_required + ' </p>' );
            }

            if ( ! password.length ) {
                validated = false;

                $password.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.password_required + ' </p>' );
            }

            if ( validated ) {

                var $btn = $form.find( '[type="submit"]' );
                var form_data = $form.serialize() + '&action=dlms_auth_register';

                $.ajax( {
                    url: _dozentlms.ajaxurl,
                    type: 'POST',
                    data: form_data,
                    beforeSend: function() {
                        $btn.attr( 'disabled', 'disabled' ).addClass( 'icon-spinner' );
                    },
                    success: function( response ) {
                        if ( response.success ) {
                            $form.trigger("reset");

                            $( '[data-target=".auth-login-tab"]' ).trigger('click');
                            $( '.auth_form_response' ).html( '<p class="form-response-success"> ' + response.data.message + ' </p>' );
                        } else if( response.data ) {
                            $( '.auth_form_response' ).html( '<p class="form-response-error"> ' + response.data.message + ' </p>' );
                        }
                    },
                    complete: function() {
                        $btn.removeAttr( 'disabled' ).removeClass( 'icon-spinner' );
                    }
                } );
            }

        },

        submitLostPasswordForm: function( e ){
            e.preventDefault();

            var $form = $( e.currentTarget );
            var $username = $form.find( '[name="lostpasasword_username"]' );
            
            $form.find( '.error-text' ).remove();
            $( '.auth_form_response' ).html( '' );

            var username = dlms_trim( $username.val() );
            var validated = true;

            if ( ! username.length ) {
                validated = false;

                $username.closest( '.dlms-form-group' ).append( '<p class="error-text"> ' + _dozentlms.username_email_required + ' </p>' );
            }

            if ( validated ) {
                var $btn = $form.find( '[type="submit"]' );
                var form_data = $form.serialize() + '&action=dlms_auth_lostpassword';

                $.ajax( {
                    url: _dozentlms.ajaxurl,
                    type: 'POST',
                    data: form_data,
                    beforeSend: function() {
                        $btn.attr( 'disabled', 'disabled' ).addClass( 'icon-spinner' );
                    },
                    success: function( response ) {
                        if ( response.success ) {
                            $form.trigger("reset");
                            $( '.auth_form_response' ).html( '<p class="form-response-success"> ' + response.data.message + ' </p>' );

                        } else if( response.data ) {
                            $( '.auth_form_response' ).html( '<p class="form-response-error"> ' + response.data.message + ' </p>' );
                        }
                    },
                    complete: function() {
                        $btn.removeAttr( 'disabled' ).removeClass( 'icon-spinner' );
                    }
                } );
            }
        },

    };

    /**
     * Start course builder
     */

    dozentlms.auth.start();

})( jQuery );

function dlms_trim(x) {
    return x.replace( /^\s+|\s+$/gm, '' );
};/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.core = {

        start: function() {
            this.addListeners();
        },

        addListeners: function() {
            document.onkeydown = this.escKeyPressed.bind( this );

            //WishList
            $( document ).on( 'click', '.toggle-wishlist-btn', this.toggleWishList.bind( this ) );

            /**
             * Course Archive Filter
             */
            $( document ).on( 'change', '#dlms-archive-filter-form', this.archiveFilter.bind( this ) );
            $( document ).on( 'click', 'button.listgrid-toggle', this.switchCourseView.bind( this ) );

            /**
             * Course Single Page
             */
            $( document ).on( 'click', '.dlms-syllabus-expand-collapse-btn', this.toggleExpandCollapse.bind( this ) );
            $( document ).on( 'click', '.dlms-module-header', this.toggleCourseModule.bind( this ) );

        },


        escKeyPressed: function( evt ) {
            evt = evt || window.event;
            var isEscape = false;
            if ( "key" in evt ) {
                isEscape = (
                    evt.key === "Escape" || evt.key === "Esc"
                );
            } else {
                isEscape = (
                    evt.keyCode === 27
                );
            }

            if ( isEscape ) {
                if ( $( '#dlms-module-form' ).length ) {
                    $( '#dlms-module-form' ).hide();
                }

                dozentlms.modal.closeModal();
            }
        },

        toggleWishList: function( e ) {
            e.preventDefault();

            if ( !_dozentlms.is_logged_in ) {
                dozentlms.login_modal.show();
                return;
            }

            var $btn = $( e.currentTarget );
            var course_id = $btn.data( 'course-id' );

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: {course_id: course_id, action: 'dozentlms_toggle_wishlist'},
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        $btn.html( response.data.btn_text );
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );
        },

        archiveFilter: function( e ){
            e.preventDefault();

            var $form = $( e.currentTarget );
            $form.submit();
        },

        switchCourseView: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var view = $btn.data( 'view' );

            if ( 'list' === view ){
                $( '.dlms-loop-courses' ).addClass( 'dlms-list-view' );
            } else {
                $( '.dlms-loop-courses' ).removeClass( 'dlms-list-view' );
            }
        },


        toggleExpandCollapse: function( e ){
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var action = $btn.data( 'action' );

            if ( 'expand' === action ) {
                $( '.dlms-module-items' ).removeClass( 'module-item-hidden' );
                $btn.data( 'action', 'collapse' );
                $btn.html( _dozentlms.collapse_modules );

                $( '.dlms-module-header' ).attr( 'data-action', 'collapse' );
            } else {
                $( '.dlms-module-items' ).addClass( 'module-item-hidden' );
                $btn.data( 'action', 'expand' );
                $btn.html( _dozentlms.expand_modules );

                $( '.dlms-module-header' ).attr( 'data-action', 'expand' );
            }

        },

        toggleCourseModule: function( e ){
            e.preventDefault();

            var $that = $( e.currentTarget );

            var action = $that.attr( 'data-action' );

            if ( 'expand' === action ) {
                $that.next( '.dlms-module-items' ).addClass( 'module-item-hidden' );
                $that.attr( 'data-action', 'collapse' );
            } else {
                $that.next( '.dlms-module-items' ).removeClass( 'module-item-hidden' );
                $that.attr( 'data-action', 'expand' );
            }

        },


    };

    /**
     * Start course builder
     */

    dozentlms.core.start();

})( jQuery );;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};
dozentlms.fcb_autosave = false;

( function( $ ){

    dozentlms.course_builder = {

        start: function() {
            this.addListeners();
            dozentlms.get_the_course_id = this.current_course_id();
        },

        addListeners: function() {
            $( document ).on( 'click', '.dlms-add-module', this.addModule.bind( this ) );
            $( document ).on( 'click', '#dlms-module-form-close', this.closeModuleForm.bind( this ) );
            $( document ).on( 'click', '.new-module-save-btn', this.saveModule.bind( this ) );
            $( document ).on( 'click', '.update-module-btn', this.updateModule.bind( this ) );
            $( document ).on( 'click', '.module-delete-btn', this.deleteModule.bind( this ) );
            $( document ).on( 'click', '.module-edit-btn', this.openModuleForm.bind( this ) );
            $( document ).on( 'click', '.btn-cancel-form', this.clearForm.bind( this ) );
            $( document ).on( 'click', '.add-new-lecture', this.addLectureForm.bind( this ) );
            $( document ).on( 'click', '.btn-save-lecture', this.lectureSave.bind( this ) );

            $( document ).on( 'click', '#cbToggleFullScreen', this.toggleFullScreen.bind( this ) );
            $( document ).on( 'fullscreenchange', '#coursebuilderWrap', this.fsChange.bind( this ) );

            $( document ).
                on( 'change', '.video-source-label [name="_video[source]"]', this.toggleVideoSource.bind( this ) );
            $( document ).on( 'click', '.module-item-delete-btn', this.deleteModuleItem.bind( this ) );

            //Edit Module Items
            $( document ).on( 'click', '.module-item-edit-btn', this.editModuleItem.bind( this ) );

            /**
             * Front-End Course Builder
             */

            $( document ).on( 'click', '#dlms-fcb-save-button', this.fcbSave.bind( this ) );
            this.fcbAutoSave();
        },

        current_course_id: function() {
            return parseInt( $( '#dozentlms_current_course_id' ).val(), 10 );
        },

        addModule: function( e ) {
            e.preventDefault();

            $( '#dlms-module-form' ).toggle();
        },

        closeModuleForm: function( e ) {
            e.preventDefault();
            $( '#dlms-module-form' ).hide();
        },

        saveModule: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );

            $( '#module-name-response' ).html( '' );
            var module_name = $( '#new-module-name' ).val().trim();
            if ( !module_name.length ) {
                $( '#module-name-response' ).
                    html( '<p class="dlms-text-danger"> ' + _dozentlms.module_name_required + ' </p>' );
                return;
            }

            var data = $btn.closest( '#dlms-module-form' ).find( 'input, textarea' ).serialize() + '&course_id='
                       + dozentlms.get_the_course_id + '&action=dozentlms_add_module';

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: data,
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        $( '#new-module-name' ).val( '' );
                        $( '#new-module-description' ).val( '' );

                        $( '#dlms-course-contents' ).html( response.data.contents );
                        dozentlms.course_contents_sort();
                        dozentlms.toaster( _dozentlms.module_created );
                        $btn.closest( '#dlms-module-form' ).hide();
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );
        },

        updateModule: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );

            var module_id = $btn.closest( '.dlms-modal' ).attr( 'data-module-id' );
            var data = $btn.closest( '.edit-module-form' ).find( 'input, textarea' ).serialize() + '&module_id='
                       + module_id + '&course_id=' + dozentlms.get_the_course_id + '&action=dozentlms_update_module';

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: data,
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        $( '#dlms-course-contents' ).html( response.data.contents );
                        dozentlms.course_contents_sort();
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );
        },

        deleteModule: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );

            var module_id = $btn.attr( 'data-module-id' );
            $btn.closest( '.cb-module' ).remove();
            $.post( _dozentlms.ajaxurl, {module_id: module_id, 'action': 'dozentlms_delete_module'} );
        },

        openModuleForm: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );

            var module_id = $btn.attr( 'data-module-id' );
            $( '.dlms-modal[data-module-id="' + module_id + '"]' ).addClass( 'show' );
        },

        clearForm: function( e ) {
            if ( e ) {
                e.preventDefault();
            }

            $( '.module-item-form-wrap' ).html( '' );
            $( '.edit-module-item-form' ).html( '' );
        },

        clickCancelBtn: function( e ) {
            $( '.btn-cancel-form' ).trigger( 'click' );
        },

        /**
         * Lecture
         */

        addLectureForm: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );

            this.clearForm();
            var $formHtml = $( '#tmpl-lecture-form' ).html();
            $btn.closest( '.cb-module' ).find( '.module-item-form-wrap' ).html( $formHtml );

            $.post( _dozentlms.ajaxurl, {'action': 'dozentlms_get_wp_editor'} ).done( function( data ) {
                if ( data.success ) {
                    $btn.closest( '.cb-module' ).find( '.wpEditorWrap' ).html( data.data.wp_editor );

                    setTimeout( function() {
                        tinymce.execCommand( 'mceRemoveEditor', false, 'lecture_content' );
                        tinymce.execCommand( 'mceAddEditor', false, "lecture_content" );
                        quicktags( {
                            id: "lecture_content", buttons:
                                'strong,em,link,block,del,ins,img,ul,ol,li,code,more,close'
                        } );
                    }, 100 );
                }
            } );
        },

        lectureSave: function( e ) {
            e.preventDefault();

            var self = this;
            var $btn = $( e.currentTarget );

            if ( !$btn.closest( '.lecture-form-html' ).find( '[name="title"]' ).val().trim().length ) {
                dozentlms.toaster( 'Lecture title field required', 'warning' );
                return;
            }

            var module_id = parseInt( $btn.closest( '.cb-module' ).attr( 'id' ).match( /\d+/ )[0], 10 );

            var content;
            var editorID = 'lecture_content';
            var editor = tinyMCE.get( editorID );
            if ( editor ) {
                content = editor.getContent();
            } else {
                content = $( '#' + editorID ).val();
            }

            var data = $btn.closest( '.lecture-form-html' ).find( 'input, textarea, select' ).serialize()
                       + '&lecture_content=' + encodeURIComponent( content ) + '&course_id='
                       + dozentlms.get_the_course_id
                       + '&module_id=' + module_id + '&action=dozentlms_lecture_save';

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: data,
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        self.clickCancelBtn();
                        $( '#dlms-course-contents' ).html( response.data.contents );
                        dozentlms.course_contents_sort();
                    } else {
                        if ( response.data && response.data.message ) {
                            dozentlms.toaster( response.data.message, 'danger' );
                        }
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );
        },

        toggleFullScreen: function( e ) {
            e.preventDefault();

            var $cbWrap = $( '#coursebuilderWrap' );
            if (
                document.fullscreenElement ||
                document.webkitFullscreenElement ||
                document.mozFullScreenElement ||
                document.msFullscreenElement
            ) {

                if ( document.exitFullscreen ) {
                    document.exitFullscreen();
                } else if ( document.mozCancelFullScreen ) {
                    document.mozCancelFullScreen();
                } else if ( document.webkitExitFullscreen ) {
                    document.webkitExitFullscreen();
                } else if ( document.msExitFullscreen ) {
                    document.msExitFullscreen();
                }
            } else {
                var element = $cbWrap.get( 0 );
                if ( element.requestFullscreen ) {
                    element.requestFullscreen();
                } else if ( element.mozRequestFullScreen ) {
                    element.mozRequestFullScreen();
                } else if ( element.webkitRequestFullscreen ) {
                    element.webkitRequestFullscreen( Element.ALLOW_KEYBOARD_INPUT );
                } else if ( element.msRequestFullscreen ) {
                    element.msRequestFullscreen();
                }
            }
        },

        fsChange: function( e ) {
            e.preventDefault();

            if ( document.fullscreenElement ) {
                $( '#coursebuilderWrap' ).addClass( 'fson' );
            } else {
                $( '#coursebuilderWrap' ).removeClass( 'fson' );
            }

        },

        toggleVideoSource: function( e ) {
            var $input = $( e.currentTarget );

            var source = $input.val().trim();

            $( '.video-source-input-wrap' ).slideUp();
            $( '.video-runtime-input-wrap' ).hide();

            if ( source ) {
                $( '.video-source-' + source ).slideDown();
                $( '.video-runtime-input-wrap' ).show();
            }

            $( '.video-source-segment-wrap' ).removeClass( 'checked' );
            $input.closest( '.video-source-segment-wrap' ).addClass( 'checked' );
        },

        deleteModuleItem: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var item_id = $btn.data( 'item-id' );
            $btn.closest( '.content-item' ).remove();

            $.post( _dozentlms.ajaxurl, {item_id: item_id, 'action': 'dozentlms_delete_module_item'} );
        },

        editModuleItem: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var item_id = $btn.data( 'item-id' );
            var item_type = $btn.data( 'item-type' );
            this.clearForm();

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: {item_id: item_id, 'action': 'dozentlms_get_module_item_form'},
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {
                        $( '#edit-module-item-form-' + item_id ).html( response.data.html );

                        if ( item_type === 'dlms_lecture' ) {
                            setTimeout( function() {
                                tinymce.execCommand( 'mceRemoveEditor', false, 'lecture_content' );
                                tinymce.execCommand( 'mceAddEditor', false, "lecture_content" );
                                quicktags( {
                                    id: "lecture_content", buttons:
                                        'strong,em,link,block,del,ins,img,ul,ol,li,code,more,close'
                                } );

                            }, 100 );
                        }
                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );
        },

        /**
         * Front-End Form
         */

        fcbSave: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            var $form = $btn.closest( 'form' );
            var autosave = dozentlms.fcb_autosave;
            dozentlms.fcb_autosave = false;

            var data = $form.serialize() + '&fcb_autosave=' + autosave + '&action=fcb_save';

            $.ajax( {
                url: _dozentlms.ajaxurl,
                type: 'POST',
                data: data,
                beforeSend: function() {
                    $btn.addClass( 'icon-spinner' );
                },
                success: function( response ) {
                    if ( response.success ) {

                    }
                },
                complete: function() {
                    $btn.removeClass( 'icon-spinner' );
                }
            } );

        },

        fcbAutoSave: function() {
            if ( !_dozentlms.fcb_auto_save || !(
                _dozentlms.current_dashboard_screen &&
                ['create-new-course', 'edit-course'].includes( _dozentlms.current_dashboard_screen.toLowerCase() )
            ) ) {
                return;
            }

            var interval = parseInt( _dozentlms.fcb_auto_save_time_interval, 10 );
            if ( interval < 30 ) {
                interval = 30;
            }
            /**
             * Save course every minute
             */
            setInterval( function() {
                dozentlms.fcb_autosave = true;

                $( '#dlms-fcb-save-button' ).trigger( 'click' );
            }, (
                1000 * interval
            ) );
        }

    }

    /**
     * Start course builder
     */

    dozentlms.course_builder.start();

})( jQuery );


;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

jQuery(document).ready(function( $ ) {
    'use strict';

    dozentlms.functions_init_load = {
        start: function() {
            this.addListeners();
            this.limitContainerMaxHeight();
        },

        addListeners: function() {
            $( document ).on( 'click', '.dlms-show-more', this.fireShowMore.bind( this ) );
        },

        limitContainerMaxHeight: function() {

            var $items = $( '.expandable-container-inner' );
            if ( $items.length ) {
                $items.each( function() {
                    var $that = $( this );
                    var height = $that.height();
                    var max_height = parseInt( $that.attr( 'data-max-height' ), 10 );
                    if ( ! max_height ) {
                        max_height = 240;
                    }

                    if ( height > max_height ) {
                        $( this ).closest( '.expandable-container' ).append(
                            '<span class="dlms-show-more-wrap"> <a href="javascript:;" class="dlms-show-more"> '
                            + _dozentlms.show_more_text + ' </a></span>' );
                    }
                } );
            }

        },

        fireShowMore: function( e ) {
            e.preventDefault();
            var $target = $( e.currentTarget );

            $target.closest( '.expandable-container' ).css( "max-height", "none" );
            $target.closest( '.dlms-show-more-wrap' ).remove();
        }

    }
    //Kick start the necessary init
    dozentlms.functions_init_load.start();

    window.dozentlms.toaster = function( message, type ) {
        if ( !type ) {
            type = 'success';
        }

        var $toasterWrap = "<div class='dozentToaster " + type + "'>" + message + "</div>";
        $( 'body' ).append( $toasterWrap );
        var $toaster = $( ".dozentToaster" ).addClass( 'show' );
        setTimeout( function() {
            $toaster.removeClass( 'show' );
        }, 3000 );
    }

    /**
     * Sort Course Contents
     */
    window.dozentlms.course_contents_sort = function() {
        if ( jQuery().sortable ) {
            $( "#cb-modules-wrap" ).sortable( {
                handle: ".module-sort-handler",
                start: function( e, ui ) {
                    ui.placeholder.css( 'visibility', 'visible' );
                },
                stop: function( e, ui ) {
                    dozentlms.sorting_contents();
                },
            } );

            $( ".cb-module-body" ).sortable( {
                connectWith: ".cb-module-body",
                handle: ".module-item-top",
                items: "div.content-item",
                start: function( e, ui ) {
                    ui.placeholder.css( 'visibility', 'visible' );
                },
                stop: function( e, ui ) {
                    dozentlms.sorting_contents();
                },
            } );

        }
    }
    dozentlms.course_contents_sort();

    window.dozentlms.sorting_contents = function() {
        var modules = {};
        $( '.cb-module' ).each( function( index, item ) {
            var module_id = parseInt( $( this ).attr( 'id' ).match( /\d+/ )[0], 10 );

            var items = {};
            $( this ).find( '.content-item' ).each( function( contentIndex, content ) {
                items[contentIndex] = parseInt( $( this ).attr( 'id' ).match( /\d+/ )[0], 10 );
            } );
            modules[index] = {'module_id': module_id, 'item_ids': items};
        } );

        $.post( _dozentlms.ajaxurl, {modules: modules, action: 'sorting_course_contents'} );
    }

    window.dozentlms.login_modal = {
        modal_selector: $( '.dlms-modal.dlms-login-modal' ),
        show: function() {
            this.modal_selector.addClass( 'show' );
        },
        hide: function() {
            this.modal_selector.removeClass( 'show' );
        }
    }

    window.dozentlms.rate_review_modal = {
        modal_selector: $( '.dlms-modal.dlms-rate-review-modal' ),
        show: function() {
            this.modal_selector.addClass( 'show' );
        },
        hide: function() {
            this.modal_selector.removeClass( 'show' );
        }
    }
});;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.media_uploader = {

        start: function() {
            this.addListeners();
        },

        addListeners: function() {
            $( document ).on( 'click', '.upload-toggle-btn', this.uploadButtonToggle.bind( this ) );
            $( document ).on( 'click', '.dlms-upload-field-wrap .field-upload-btn', this.chooseMedia.bind( this ) );
            $( document ).on( 'click', '.dlms-upload-field-wrap .field-clear-btn', this.clearMedia.bind( this ) );
            $( document ).on( 'click', '.dlms-upload-field-wrap .field-close-btn', this.cancelUploadButtonAction.bind( this ) );
        },


        uploadButtonToggle: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            $btn.siblings( '.field-actions-wrap' ).toggle();

            var rt = ( $( window ).width() - ( $btn.offset().left + $btn.outerWidth() ) );

            if ( rt < 150 ) {
                $btn.siblings( '.field-actions-wrap' ).css( 'left', 0 );
            }

        },

        chooseMedia: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            $btn.closest( '.field-actions-wrap' ).hide();

            var frame, attachment;
            if ( frame ) {
                frame.open();
                return;
            }
            frame = wp.media( {
                title: _dozentlms.wp_select_media,
                button: {
                    text: _dozentlms.wp_use_media
                },
                multiple: false
            } );

            frame.on( 'open', function() {

                var media_ids = $btn.closest( '.dlms-upload-field-wrap' ).find( 'input.media-field' ).val().
                                     split( ',' );

                /* get the selection object for the wp.media frame */
                var selection = frame.state().get( 'selection' );
                if ( media_ids && media_ids.length ) {
                    $.each( media_ids, function( idx, val ) {
                        attachment = wp.media.attachment( val );
                        attachment.fetch();
                        selection.add( attachment ? [attachment] : [] );
                    } );
                }
            } );

            frame.on( 'select', function() {
                attachment = frame.state().get( 'selection' ).first().toJSON();

                $btn.closest( '.dlms-upload-field-wrap' ).find( 'input.media-field' ).val( attachment.id );
                $btn.closest( '.dlms-upload-field-wrap' ).find( 'img.upload-field-thumbnail' ).
                     attr( 'src', attachment.url );

                if ( $btn.closest( '.dlms-upload-field-wrap' ).find( '.uploaded-media-info' ).length ) {
                    var fileInfoHtml = '<p class="media-file-name"> <strong> ' + _dozentlms.media + ' : </strong> <span> ' + attachment.filename + ' </span> </p>';

                    fileInfoHtml += '<p class="media-file-size"> <strong> ' + _dozentlms.size + ' : </strong> <span> ' + attachment.filesizeHumanReadable + ' </span> </p>';

                    $btn.closest( '.dlms-upload-field-wrap' ).find( '.uploaded-media-info' ).html( fileInfoHtml );
                }
            } );

            frame.open();
        },

        clearMedia: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            $btn.closest( '.field-actions-wrap' ).hide();
            $btn.closest( '.dlms-upload-field-wrap' ).find( 'input.media-field' ).val( '' );
            $btn.closest( '.dlms-upload-field-wrap' ).find( 'img.upload-field-thumbnail' ).attr( 'src', _dozentlms.placeholder_src );
            $btn.closest( '.dlms-upload-field-wrap' ).find( '.uploaded-media-info' ).html( '' );
        },

        cancelUploadButtonAction: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            $btn.closest( '.field-actions-wrap' ).toggle();
        }

    }

    /**
     * Start course builder
     */

    dozentlms.media_uploader.start();

})( jQuery );


;/****************************************************************************
 * DozentLMS v1.0.0
 * Copyright 2021 | DozentLMS | https://www.dozentlms.com
 ****************************************************************************/

window.dozentlms = window.dozentlms || {};

( function( $ ){

    dozentlms.modal = {

        start: function() {
            this.addListeners();
        },

        addListeners: function() {
            $( document ).on( 'click', '[data-toggle="modal"]', this.openModal.bind( this ) );
            $( document ).on( 'click', '.dlms-modal .modal-close', this.closeModal.bind( this ) );
        },

        openModal: function( e ) {
            e.preventDefault();

            var $btn = $( e.currentTarget );
            $( $btn.attr( 'data-target' ) ).addClass( 'show' );
        },

        closeModal: function( e ) {
            if ( e ) {
                e.preventDefault();
            }

            $( '.dlms-modal' ).removeClass( 'show' );
        }

    };

    /**
     * Start course builder
     */

    dozentlms.modal.start();

})( jQuery );



//# sourceMappingURL=main.js.map